<?php
namespace WfpFundraising\Apps;
if ( ! defined( 'ABSPATH' ) ) die( 'Forbidden' );
/**
 * Class Name : Content - This access for public page
 * Class Type : Normal class
 *
 * initiate all necessary classes, hooks, configs
 *
 * @since 1.0.0
 * @access Public
 */
use \WfpFundraising\Apps\Settings as Settings; 

Class Content{
	
	// declare custom post type here
	 const post_type = 'wp-fundraising';
	 
	 const post_type_review = 'wfp-review';
	 
	 // donation table name
	 const table_name = 'wdp_fundraising';
	 
	 private static $instance;
	 
	 public $user_id = 0;
    /**
     * Construct the cpt object
     * @since 1.0.0
     * @access public
     */
	 public function _init($load = true){
		if($load){
			$user_id = get_current_user_id();
			// Load css file in front-ent 
			add_action( 'wp_enqueue_scripts', [$this, 'wfp_donation_css_loader_public' ] );
			
			// action init rest	
			add_action('init', [ $this, 'wfp_init_rest' ]); 	
			
			// active donatation message from paypal	
			add_action('init', [ $this, 'wfp_donate_return_message' ]); 	
			
			// add shortcode options
			add_shortcode( 'wfp-forms', [ $this, 'wfp_fund_donation_shortcode' ] );
			
			// add shortcode for dashboard page
			add_shortcode( 'wfp-dashboard', [ $this, 'wfp_dashboard_content_shortcode' ] );
			// add shortcode for success page
			add_shortcode( 'wfp-success', [ $this, 'wfp_success_content_shortcode' ] );
			// add shortcode for checkout page
			add_shortcode( 'wfp-checkout', [ $this, 'wfp_checkout_content_shortcode' ] );
			// add shortcode for cancel page
			add_shortcode( 'wfp-cancel', [ $this, 'wfp_cancel_content_shortcode' ] );
			// add shortcode for campign page
			add_shortcode( 'wfp-campaign', [ $this, 'wfp_list_campaign_shortcode' ] );
			  			
			// single page template
			add_filter( 'single_template', [ $this, 'wfp_single_page' ]);	
			
			// dashboard content modify hook
			add_filter( 'the_content', [ $this, 'wfp_content_replace_for_dashboard_page'] );
			
			// checkout content modify hook
			add_filter( 'the_content', [ $this, 'wfp_content_replace_for_checkout_page'] );	
			
			// list of campaign content modify hook
			add_filter( 'the_content', [ $this, 'wfp_content_replace_for_campaign_page'] );
			
			// add meta tag in head of html
			add_action( 'wp_head', [ $this, 'wfp_insert_fb_in_head' ], 5 );
			

			add_filter('wfp_single_social_providers', [ $this , 'add_share_link']);

			// Include Dashboard Page In manu
			//add_filter('wp_nav_menu_items', [ $this, 'wfp_add_dashboard_page_menu'], 10, 2);
			//add_filter( 'wp_nav_menu_{$menu->slug}_items', [ $this, 'wfp_add_dashboard_page_menu'] );
			
			//add_filter( 'sidebars_widgets', [ $this, 'remove_specific_widget'] );
			
		}	
	 }
	 
	  /**
     * Custom Post type : static method
     * @since 1.0.0
     * @access public
     */
	 public static function post_type(){
		 return self::post_type;
	 }
	 
	 // share link added
	 public function add_share_link( $link ){
		unset($link['linkedin']);
		$link['link'] = [ 'label' => 'Copy Link', 'onclick' => 'wfp_copy_link(this)', 'url' =>'', 'params' => ['url' => '[%url%]'], 'icon' => 'met-social met-social-link'];
		return $link;
	}
	 /**
     * Custom Post type : static method
     * @since 1.0.0
     * @access public
     */
	 public static function wfp_donate_table($table = ''){
		 global $wpdb;
		 if( strlen($table) > 0){
			 return $wpdb->prefix.$table;
		 }else{ 
			return $wpdb->prefix.self::table_name;
		 }
	 }
	 /**
     * Donate wfp_insert_fb_in_head() .
     * Method Description: Add meta data for share facebook
     * @since 1.0.0
     * @access for public
     */ 
	 public function wfp_insert_fb_in_head(){
		 global $post;
		 if( get_post_type( $post ) === self::post_type() && is_single() ){ 
			if( !is_singular()){
				return;
			}
			$current_id = get_current_user_id();
			$user = get_userdata( $current_id );
			$userName = 'xpeedstudio';
			if(is_object($user)){
				$userName = isset($user->data->user_nicename) ? $user->data->user_nicename : '';
			}
			$descrpition = '';
			if(strlen($post->post_excerpt) > 2){
				$descrpition = $post->post_excerpt;
			}
			$meta = '';
			$meta .= '<meta property="fb:admins" content="'.$userName.'"/>';
			$meta .= '<meta property="og:title" content="' . get_the_title() . '"/>';
			$meta .= '<meta property="og:type" content="article"/>';
			$meta .= '<meta property="og:description" content="' . $descrpition . '"/>';
			$meta .= '<meta property="og:url" content="' . get_permalink() . '"/>';
			$meta .= '<meta property="og:site_name" content="'.get_bloginfo().'"/>';
			if(!has_post_thumbnail( $post->ID )) { 
				$gallery_array = explode(',', get_post_meta( $post->ID ,'wfp_portfolio_gallery',true));
				if (is_array($gallery_array) && sizeof($gallery_array)) {
					$default_image = wp_get_attachment_thumb_url($gallery_array[0]); 
					$meta .= '<meta property="og:image" content="' . $default_image . '"/>';
				}
				
			}else{
				$thumbnail_src = wp_get_attachment_image_src( get_post_thumbnail_id( $post->ID ), 'medium' );
				$meta .= '<meta property="og:image" content="' . esc_attr( $thumbnail_src[0] ) . '"/>';
			}
			echo $meta;
		  }
	 }
	
	 public function wfp_single_page($single){
	  global $post;
	  $formSetting = $formGoalData = $multiPleData = $getMetaData = [];
	  $donation_format = 'donation';
	  if( get_post_type( $post ) === self::post_type() && is_single() && ($post->post_status === 'publish') )
      { 
		if ( file_exists( WFP_FUNDRAISING_PLUGIN_PATH.'views/public/fundraising/single-page/single-fundraising.php' ) ) {
			// post meta of form data 
			
			global $getMetaData;
			$metaKey = 'wfp_form_options_meta_data';
			$metaDataJson = get_post_meta( $post->ID, $metaKey, false );
			$getMetaData = json_decode(json_encode(end($metaDataJson)));
			
			global $donation_format;
			$donation_format = isset($getMetaData->donation->format) ? $getMetaData->donation->format : 'donation';
			
			// setting data
			global $formSetting;
			$formSetting = isset($getMetaData->form_settings) ? $getMetaData->form_settings : [];
			
			// form goal data
			global $formGoalData;
			$formGoalData = isset($getMetaData->goal_setup) ? $getMetaData->goal_setup : (object)[ 'enable' => 'No', 'goal_type' => 'terget_goal'];
			
			global $multiPleData;
			$multiPleData = isset($getMetaData->pledge_setup->multi->dimentions) && sizeof($getMetaData->pledge_setup->multi->dimentions) ? $getMetaData->pledge_setup->multi->dimentions : [ ];
			
			global $formDesignData;
			$formDesignData = isset($getMetaData->form_design) ? $getMetaData->form_design : (object)[ 'styles' => 'all_fields', 'continue_button' => 'Continue', 'submit_button' => 'Donate Now'];
			
			global $recentDonation;
			$whereQuery = " AND form_id = ".$post->ID." AND status IN('Active')";
			$recentDonation = $this->wfp_get_result('', $whereQuery);

			// theme directory for template redirect..
			
			$files_theme = trailingslashit( get_template_directory()).'wp-fundraising/single-page/single-fundraising.php';
			if( file_exists( $files_theme )){
				return $files_theme;
			}
			
			// default template
			return WFP_FUNDRAISING_PLUGIN_PATH.'views/public/fundraising/single-page/single-fundraising.php';
		}
      }
	  return $single;
	}
	
	/**
     * Donate wfp_init_rest .
     * Method Description: load rest api
     * @since 1.0.0
     * @access for public
     */ 
	 public function wfp_init_rest(){
		add_action( 'rest_api_init', function () {
		  register_rest_route( 'xs-donate-form', '/donate-submit/(?P<formid>\w+)/', 
			array(
				'methods' => 'POST',
				'callback' => [$this, 'wfp_action_rest_donate_submit'],
			  ) 
		  );
		  
		  register_rest_route( 'xs-fundraising-form', '/campaign-submit/(?P<formid>\w+)/', 
			array(
				'methods' => 'POST',
				'callback' => [$this, 'wfp_action_rest_campaign_submit_by_user'],
			  ) 
		  );
		  
		  register_rest_route( 'xs-profile-form', '/billing-submit/(?P<formid>\w+)/', 
			array(
				'methods' => 'POST',
				'callback' => [$this, 'wfp_action_rest_profile_submit_by_user'],
			  ) 
		  );
		  
		  register_rest_route( 'xs-password-form', '/password-submit/(?P<formid>\w+)/', 
			array(
				'methods' => 'POST',
				'callback' => [$this, 'wfp_action_rest_password_submit_by_user'],
			  ) 
		  );
		  
		  register_rest_route( 'xs-login-form', '/user-login/(?P<formid>\w+)/', 
			array(
				'methods' => 'POST',
				'callback' => [$this, 'wfp_action_rest_login_user'],
			  ) 
		  );
		  register_rest_route( 'xs-register-form', '/user-register/(?P<formid>\w+)/', 
			array(
				'methods' => 'POST',
				'callback' => [$this, 'wfp_action_rest_register_user'],
			  ) 
		  );
		  
		   register_rest_route( 'xs-review-form', '/user-review/(?P<formid>\w+)/', 
			array(
				'methods' => 'POST',
				'callback' => [$this, 'wfp_action_rest_user_review'],
			  ) 
		  );
		  
		   register_rest_route( 'xs-update-form', '/user-update/(?P<formid>\w+)/', 
			array(
				'methods' => 'POST',
				'callback' => [$this, 'wfp_action_rest_user_update'],
			  ) 
		  );

		  // delete review data
		  register_rest_route( 'xs-review-form', '/delete-review/(?P<formid>\w+)/', 
			array(
				'methods' => 'GET',
				'callback' => [$this, 'wfp_action_rest_review_delete'],
			  ) 
		  );
		  
		   // update review data
		   register_rest_route( 'xs-review-form', '/update-review/(?P<formid>\w+)/', 
		   array(
			   'methods' => 'GET',
			   'callback' => [$this, 'wfp_action_rest_review_update'],
			 ) 
		 );
		} );
		
    }
    /**
     * Donate wfp_action_rest_donate_submit .
     * Method Description: Action donate form submit when click this donate button.
     * @since 1.0.0
     * @access for public
     */ 
	public function wfp_action_rest_donate_submit(\WP_REST_Request $request ){
		$return = ['success' => [], 'error' => [] ];
		$error = false;
		global $wpdb;
		
		$formId = isset($request['formid']) ? $request['formid'] : 0;
		
		$check_post = get_post($formId);
		if( !is_object($check_post) && !property_exists($check_post, 'ID')){
			$return['error'] = esc_html__('Sorry invalid form of Donation.', 'wp-fundraising');
			$error = true;
			return $return;
		}	
		
		$metaKey = 'wfp_form_options_meta_data';
		$metaDataJson = get_post_meta( $check_post->ID, $metaKey, false );
		
		// get settings information
		$getMetaData = json_decode(json_encode(end($metaDataJson)));
		
		// get payment Getway information
		$optinsKey = 'wfp_payment_options_data';
		$getOptionsData = get_option( $optinsKey );
		$gateWaysData = isset($getOptionsData['gateways']['services']) ? $getOptionsData['gateways']['services'] : [];
		
		// option currency
		$metaGeneralKey = 'wfp_general_options_data';
		$getMetaGeneralOp = get_option( $metaGeneralKey );
		$getMetaGeneral = isset($getMetaGeneralOp['options']) ? $getMetaGeneralOp['options'] : [];
		
		$defaultCurrencyInfo = isset($getMetaGeneral['currency']['name']) ? $getMetaGeneral['currency']['name'] : 'US-USD';
		
		$data = isset($request['xs_donate_data_submit']) ? $request['xs_donate_data_submit'] : [];
		
		$data = \WfpFundraising\Apps\Settings::sanitize( $data );
		
		$email_address = $first_name = $last_name = '';
		
		$additionalFiled = isset($data['additonal']) ? $data['additonal'] : [];
		//$addData = serialize($additionalFiled);
		
		// additional filed from setup data
		$multiFiledData = isset($getMetaData->form_content->additional->dimentions) && sizeof($getMetaData->form_content->additional->dimentions) ? $getMetaData->form_content->additional->dimentions : [ (object)['type' => 'text', 'lebel' => 'First Name', 'default' => '', 'required' => 'Yes'], (object)['type' => 'text', 'lebel' => 'Last Name', 'default' => '', 'required' => 'Yes'], (object)['type' => 'text', 'lebel' => 'Email Address', 'default' => '', 'required' => 'Yes']];
		
		$additionalEnable = !isset($getMetaData->form_content->additional) ? 'check' : '';
		if( isset($getMetaData->form_content->additional->enable) && $getMetaData->form_content->additional->enable == 'Yes' ){
			$additionalEnable = 'check';
		}
		
		$metaKey = [];
		$userMata = [];
			
		if(is_array($multiFiledData) && sizeof($multiFiledData) > 0 && $additionalEnable == 'check'){
			foreach($multiFiledData AS $multi):
				$lebelFiled = isset($multi->lebel) ? $multi->lebel : '';
				if( strlen($lebelFiled) > 0 ){
					$nameFiled = str_replace(['  ', '-', ' ', '.', ',', ':'], '_', strtolower(trim($lebelFiled)) );
					
					$filedValue = isset($additionalFiled[$nameFiled]) ? $additionalFiled[$nameFiled] : '';
					
					if(preg_match_all('/\b(first|full)\b/i', strtolower($lebelFiled), $matches)){
						$first_name = $filedValue;
					}
					
					if(preg_match_all('/\b(last|nick)\b/i', strtolower($lebelFiled), $matches)){
						$last_name = $filedValue;
					}
					
					
					if( \WfpFundraising\Apps\Settings::valid_email($filedValue) ){
						$email_address = $filedValue;
					}
					
					if(preg_match_all('/\b(email)\b/i', strtolower($lebelFiled), $matches)){
						$email_address = $filedValue;
					}
					
					$required = isset($multi->required) ? $multi->required : '';
					if($required == 'Yes'){
						if( strlen($filedValue) <= 0):
							$return['error'] = 'Enter '.$lebelFiled;
							$error = true;
						endif;
					}
					
					$metaKey['_wfp_'.$nameFiled] = $filedValue;
					// set user meta
					$userMata['_wfp_'.$nameFiled] = $filedValue;
				}
			endforeach;
		}
		
		$xs_payment_method  = isset($data['payment_method']) ? trim($data['payment_method']) : '';
		
		// check payment method
		if( strlen($xs_payment_method) <= 0):
			$return['error'] = esc_html__('Enter select payment method', 'wp-fundraising');
			$error = true;
		endif;
		
		// check donate amount
		$donate_amount = isset($data['donate_amount']) ? $data['donate_amount'] : 0;
		$addition_fees = isset($data['addition_fees']) ? $data['addition_fees'] : 0;
		$addition_fees_amount = isset($data['addition_fees_amount']) ? $data['addition_fees_amount'] : 0;
		$addition_fees_type = isset($data['addition_fees_type']) ? $data['addition_fees_type'] : '';
		if(strlen($donate_amount) <= 0 ):
			$return['error'] = esc_html__('Enter donate amount', 'wp-fundraising');
			$error = true;
		endif;
		
		//payment_type
		$fundraising_type = isset($data['payment_type']) ? $data['payment_type'] : 'donation';
		$pledge_id = isset($data['pledge_id']) ? $data['pledge_id'] : 0;
		$index = isset($data['index']) ? $data['index'] : -10;
		
		$formDonation = isset($getMetaData->donation) ? $getMetaData->donation : [];
		if(isset($formDonation->set_limit->enable) && $formDonation->set_limit->enable == 'Yes'){
			$minPrice = isset($formDonation->set_limit->min_amt) ? $formDonation->set_limit->min_amt : 0;
			$maxPrice = isset($formDonation->set_limit->max_amt) ? $formDonation->set_limit->max_amt : 0;
			
			if($donate_amount < $minPrice){
				$return['error'] = esc_html__('Sorry! minimum donate amount: ', 'wp-fundraising').$minPrice;
				$error = true;
			}
			if($donate_amount > $maxPrice && $maxPrice != 0){
				$return['error'] = esc_html__('Sorry! max donate amount: ', 'wp-fundraising').$maxPrice;
				$error = true;
			}
		}
		
		/*Check user*/
		$userId = 0;
		if(is_user_logged_in()){
			$userId = get_current_user_id();
		}else{
			if(email_exists($email_address)){
				$userId = email_exists($email_address);
			}else{
				$userdata = [];
				$userdata['user_nicename'] = $first_name;
				$userdata['display_name'] = $first_name.' '.$last_name;
				$userdata['user_email'] = $email_address;
				$userdata['user_login'] = current(explode('@', $email_address));
				$userdata['user_pass'] = '123456';
				if( strlen($email_address) > 8 && \WfpFundraising\Apps\Settings::valid_email($email_address) ){
					$userId = wp_insert_user( $userdata ) ;
					if ( is_wp_error( $userId ) ) {
						$userId = 0;
					}else{
						 $userStatus = 1;
						 // set meta data for user information
						 $userMata['nickname'] = $first_name;
						 $userMata['first_name'] = $first_name;
						 $userMata['last_name'] = $last_name;
						 $userMata['description'] = '';
						 $userMata['_wfp_email_address'] = $email_address;
						 $userMata['_wfp_first_name'] = $first_name;
						 $userMata['_wfp_last_name'] = $last_name;
						 if( is_array($additionalFiled) && sizeof($additionalFiled) > 0):
							foreach($additionalFiled as $kk=>$vv):						 
								$userMata['_wfp_'.$kk] = $vv;
							endforeach;
						endif;
						 
						 foreach($userMata as $k=>$v){
							update_user_meta($userId, $k, $v);
						 }
						 
						 // send mail in user email
						 $subject = 'Welcome new Account of '.get_bloginfo('name');
						 $message = '<h3>Welcome '.$first_name.' '.$last_name.'</h3>
							<p>Thanks for Create new account of '.get_bloginfo('name').'</p>
							<p><strong>Account Login Info:</strong><p>
							<p>User Email: '.$email_address.'<p>
							<p>Login Name: '.$userdata['user_login'].'<p>
							<p>Password: 123456<p>
							<p>Login Url: '.get_site_url().'/wfp-login/<p>
						 ';
						 
						 $headers[] = 'Content-Type: text/html; charset=UTF-8';
						 $headers[] = 'From: '.get_bloginfo('name').' <'.get_bloginfo('admin_email').'>';
						 $headers[] = 'Bcc: '.get_bloginfo('admin_email').'';
						 wp_mail(  $email_address, $subject, $message, $headers); 
					}
				}
			}
		}
		
		if(!$error){
			
			$getMetaGeneralPage = isset($getMetaGeneral['pages']) ? $getMetaGeneral['pages'] : [];
			
			$successPage = isset($getMetaGeneralPage['success']) ? $getMetaGeneralPage['success'] : 'wfp-success';
			$cencelPage = isset($getMetaGeneralPage['cancel']) ? $getMetaGeneralPage['cancel'] : 'wfp-cancel';
			
			$checkoutPage = isset($getMetaGeneralPage['checkout']) ? $getMetaGeneralPage['checkout'] : 'wfp-checkout';
			
			$tableName = self::wfp_donate_table();
			
			$typePay = 'No';
			$status = 'Review';
			$url = '';
			if($xs_payment_method == 'online_payment' || $xs_payment_method == 'stripe_payment'){
				$status = 'Pending';
			}
			$textShuffle = '@ABCDEFGHIJKLMNOPQRSTUVWXYZ0123456789';
			
			$invoiceToken = substr(str_shuffle($textShuffle), 0, 6).'-'.time();
			
			
			$wpInsrtr = [
				'donate_amount' => $donate_amount,
				'form_id' => $formId,
				'invoice' => $invoiceToken,
				'user_id' => $userId,
				'email' => $email_address,
				'fundraising_type' => $fundraising_type,
				'pledge_id' => $pledge_id,
				'payment_gateway' => $xs_payment_method,
				'date_time' => date("Y-m-d"),
				'status' => $status,
			];
			if( $wpdb->insert($tableName, $wpInsrtr) ) :
				
				
				$id_insert = $wpdb->insert_id;
				$currencyInfo = explode('-', $defaultCurrencyInfo);
				
				$metaKey['_wfp_email_address'] = $email_address;
				$metaKey['_wfp_user_id'] = $userId;
				$metaKey['_wfp_first_name'] = $first_name;
				$metaKey['_wfp_last_name'] = $last_name;
				$metaKey['_wfp_additional_data'] = $additionalFiled;
				$metaKey['_wfp_form_id'] = $formId;
				$metaKey['_wfp_donate_id'] = $id_insert;
				$metaKey['_wfp_pledge_id'] = $pledge_id;
				$metaKey['_wfp_order_key'] = 'wfp_'.$id_insert;
				$metaKey['_wfp_invoice'] = $invoiceToken;
				$metaKey['_wfp_order_shipping'] = 0;
				$metaKey['_wfp_order_shipping_tax'] = 0;
				$metaKey['_wfp_order_total'] = $donate_amount;
				$metaKey['_wfp_order_tax'] = 0;
				$metaKey['_wfp_addition_fees'] = $addition_fees;
				$metaKey['_wfp_addition_fees_amount'] = $addition_fees_amount;
				$metaKey['_wfp_addition_fees_type'] = $addition_fees_type;
				$metaKey['_wfp_country'] = current($currencyInfo);
				$metaKey['_wfp_currency'] = end($currencyInfo);
				$metaKey['_wfp_fundraising_type'] = $fundraising_type;
				$metaKey['_wfp_payment_type'] = 'default';
				$metaKey['_wfp_payment_gateway'] = $xs_payment_method;
				$metaKey['_wfp_date_time'] = date("Y-m-d H:i:s");
				
				
				// insert meta
				foreach($metaKey as $k=>$v){
					self::wfp_update_meta($id_insert, $k, $v, true);
				}
				
				if( $index >= 0 ){
					$metaKey = 'wfp_form_options_meta_data';
					$metaDataJson = get_post_meta( $formId, $metaKey, false );
					$getMetaData = json_decode(json_encode(end($metaDataJson)));
					$multiPleData = isset($getMetaData->pledge_setup->multi->dimentions) && sizeof($getMetaData->pledge_setup->multi->dimentions) ? $getMetaData->pledge_setup->multi->dimentions : [ ];
					
					if(isset($multiPleData[$index])){
						$data = json_encode((array) $multiPleData[$index]);
						update_user_meta($userId, '_wfp_pledge_user__'.$formId.'__'.$pledge_id.'', $data);
					}
				}
				
				$otder_page = get_site_url().'/'.$checkoutPage.'?wfporder=true&id-order='.str_rot13($invoiceToken).'&target='.$formId;
				
				
				if($xs_payment_method == 'online_payment'){
					
					$infoData = isset($gateWaysData[$xs_payment_method]['setup']) ? $gateWaysData[$xs_payment_method]['setup'] : [];
					$typePay = isset($infoData['paypal_sandbox']) ? $infoData['paypal_sandbox'] : 'No';
					$paypalEmail = isset($infoData['paypal_email']) ? $infoData['paypal_email'] : '';
					$invoice_prefix = isset($infoData['invoice_prefix']) ? $infoData['invoice_prefix'] : 'RES-DONE-';
					$identity = isset($infoData['payPal_identity_token']) ? $infoData['payPal_identity_token'] : '';
					
					
					if($typePay == 'Yes'){
						$url .= 'https://www.sandbox.paypal.com/cgi-bin/webscr?';	
					}else{
						$url .= 'https://www.paypal.com/cgi-bin/webscr?';
					}
					
					$options = [
						'cost' => 12,
					];
					
					$dataUrl = [
						'cmd' => '_xclick',
						'business' => $paypalEmail,
						'item_name' => $check_post->name,
						'item_number' => $check_post->ID,
						'tx' => $invoice_prefix.$invoiceToken,
						'custom' => 'RESDONE'.$check_post->ID.$id_insert,
						'amount' => $donate_amount,
						'no_shipping' => 0,
						'payer_email' => $email_address,
						'no_note' => 1,
						'currency_code' => 'USD',
					];
					if(strlen($identity) > 0){
						$dataUrl['at'] = $identity;
					}
					
					if(strlen($successPage) > 0){
						$dataUrl['return'] = get_site_url().'/'.$successPage.'?donatestatus=success&token='.str_rot13($invoiceToken).'&target='.$formId.'&key='.str_rot13($id_insert);
						
					}else{
						$dataUrl['return'] = get_site_url().'?donatestatus=success&token='.str_rot13($invoiceToken).'&target='.$formId.'&key='.str_rot13($id_insert);
						
					}
					if(strlen($cencelPage) > 0){
						$dataUrl['cancel_return'] = get_site_url().'/'.$cencelPage.'?donatestatus=cancel&token='.str_rot13($id_insert).'&key='.str_rot13($invoiceToken);
					}else{
						$dataUrl['cancel_return'] = get_site_url().'?donatestatus=cancel&token='.str_rot13($id_insert).'&key='.str_rot13($invoiceToken);
					}
					
					$url .= http_build_query($dataUrl, '', '&');
	
				}else if($xs_payment_method == 'stripe_payment'){
					$infoData = isset($gateWaysData[$xs_payment_method]['setup']) ? $gateWaysData[$xs_payment_method]['setup'] : [];
					$typePay = isset($infoData['stripe_sandbox']) ? $infoData['stripe_sandbox'] : 'No';
					
					$image_url = isset($infoData['image_url']) ? $infoData['image_url'] : '';
					
					if(strlen($successPage) > 0){
						$return_url = get_site_url().'/'.$successPage.'?donatestatus=success&token='.str_rot13($invoiceToken).'&target='.$formId.'&key='.str_rot13($id_insert);
					}else{
						$return_url = get_site_url().'?donatestatus=success&token='.str_rot13($invoiceToken).'&target='.$formId.'&key='.str_rot13($id_insert);
					}
					if(strlen($cencelPage) > 0){
						$cancel_return = get_site_url().'/'.$cencelPage.'?donatestatus=cancel&token='.str_rot13($id_insert).'&key='.str_rot13($invoiceToken);
					}else{
						$cancel_return = get_site_url().'?donatestatus=cancel&token='.str_rot13($id_insert).'&key='.str_rot13($invoiceToken);
					}
					if($typePay == 'Yes'){
						$keys = isset($infoData['test_publishable_key']) ? $infoData['test_publishable_key'] : 'pk_test_sbxBoppU6hqfE6bmRYS5Wczd002Ze8bdUS';
					}else{
						$keys = isset($infoData['live_publishable_key']) ? $infoData['live_publishable_key'] : 'pk_live_sbxBoppU6hqfE6bmRYS5Wczd002Ze8bdUS';
					}
					if(strlen(trim($image_url)) < 5){
						$image_url = 'https://stripe.com/img/documentation/checkout/marketplace.png';
					}
					
					$return['success']['keys'] = $keys;
					$return['success']['image_url'] = $image_url;
					$return['success']['return_url'] = $return_url;
					$return['success']['cancel_return'] = $cancel_return;
					$return['success']['name_post'] = $check_post->name;
					$return['success']['description'] = $check_post->ID;
					$return['success']['amount'] = $donate_amount;
					$url = get_site_url();
				}
				
				$return['success']['message'] = esc_html__('Successfully donation. ', 'wp-fundraising');
				$return['success']['type'] = $xs_payment_method;
				$return['success']['url'] = $url;
				$return['success']['check_id'] = $invoiceToken;
				$return['success']['order_page'] = $otder_page;
			else:
				$return['error'] = esc_html__('Something is wrong', 'wp-fundraising');
			endif;
		}
		
		return $return;
	}
	
	// return error message
	public function wfp_donate_return_message(){
		$returnData = isset($_GET['donatestatus']) ? Settings::sanitize($_GET['donatestatus']) : '';
		$returnDatatoken = isset($_GET['token']) ? str_rot13(Settings::sanitize($_GET['token'])) : 0;
		$returnkey = isset($_GET['key']) ? str_rot13(Settings::sanitize($_GET['key'])) : 0;
		if(in_array($returnData , ['success', 'cancel']) && !empty($returnDatatoken)){			
			global $wpdb;
			$tableName = self::wfp_donate_table();
			
			if($returnData == 'success'){
				if( $wpdb->update($tableName, ['status' => 'Active'], ['status' => 'Pending', 'invoice' => $returnDatatoken, 'donate_id' => $returnkey]) ) {
						
				}
			}else if($returnData == 'cancel'){
				if( $wpdb->update($tableName, ['status' => 'DeActive'], ['status' => 'Pending', 'donate_id' => $returnDatatoken, 'invoice' => $returnkey]) ) {
					
				}
			}	
		}
	} 
	
	
	// campaingn for submit by front-end
	/**
     * Donate wfp_action_rest_campaign_submit_by_user .
     * Method Description: Campaign form submit from Dashboard
     * @since 1.0.0
     * @access for public
     */
	public function wfp_action_rest_campaign_submit_by_user( \WP_REST_Request $request ){
		
		$return = ['success' => [], 'error' => [] ];
		$error = false;
		$post_id = 0;
		$userId = get_current_user_id();
		if(empty($userId) || $userId == 0){
			$return['error'] = __('Something error.', 'wp-fundraising');
			return $return;
		}
		
		$formId = isset($request['formid']) ? intval($request['formid']) : 0;
		$post = (array) isset($request['campaign_post']) ? $request['campaign_post'] : [];
		$meta_post = (array) isset($request['campaign_meta_post']) ? Settings::sanitize($request['campaign_meta_post']) : [];
		$update_post = isset($request['update_post']) ? intval($request['update_post']) : 0;
		// post entry
		
		if($update_post > 0){
			$upd = get_post($update_post);
			if(isset($upd->post_author) && $upd->post_author == get_current_user_id()){
				if(in_array($upd->post_status, ['draft', 'publish', 'pending'])){
					$post['ID'] = $update_post;
					wp_update_post( $post, false );
					$post_id = $update_post;
				}else{
					$return['error'] = __('Sorry could\'t update this campaign', 'wp-fundraising');
					return $return;
				}
			}
		}else{
			$post['post_type'] = self::post_type();
			$post['post_status'] = 'pending';
			$post_id = (int) wp_insert_post($post);
			update_post_meta(  $post_id , '__wfp_campaign_status', 'Publish');
		}
		if($post_id > 0){
			// added post categories
			$getCategories = (array) isset($meta_post['post_category']) ? $meta_post['post_category'] : [];
			if(is_array($getCategories) && sizeof($getCategories) > 0){
				wp_set_object_terms( $post_id, $getCategories, 'wfp-categories', true );
			}
			
			// added tags
			$getTags = (string) isset($meta_post['post_tags']) ? $meta_post['post_tags'] : '';
			$getTags = explode(',', $getTags);
			
			if(is_array($getTags) && sizeof($getTags) > 0){
				wp_set_object_terms( $post_id, $getTags, 'wfp-tags', true );
			}
			
			$generateMeta = [];
			
			// get setup data
			$metaSetupKey = 'wfp_setup_services_data';
			$getSetUpData =  get_option( $metaSetupKey );
			$setupData = isset($getSetUpData['services']) ? $getSetUpData['services'] : [];
			$foundingTyepe = isset($setupData['campaign']) ? $setupData['campaign'] : 'donation';
			
			// step donation
			$generateMeta['donation']['format'] = 'crowdfunding';
			$generateMeta['donation']['type'] = 'fixed-lebel';
			$generateMeta['donation']['multi']['dimentions'] =  [ (object)['price' => '1.00', 'lebel' => 'Basic'] ];
			$generateMeta['donation']['fixed']['price'] = isset($meta_post['donation']['fixed']['price']) ? $meta_post['donation']['fixed']['price'] : 1;
			$generateMeta['donation']['fixed']['lebel'] = '';
			$generateMeta['donation']['display'] = 'boxed';
			
			$setLimitMin = (double) isset($meta_post['set_limit']['min_amt']) ? $meta_post['set_limit']['min_amt'] : 0;
			$setLimitMax = (double) isset($meta_post['set_limit']['max_amt']) ? $meta_post['set_limit']['max_amt'] : 0;
			
			$generateMeta['donation']['set_limit']['enable'] = ($setLimitMin > 0 || $setLimitMax > 0) ? 'Yes' : 'No';
			$generateMeta['donation']['set_limit']['min_amt'] = $setLimitMin;
			$generateMeta['donation']['set_limit']['max_amt'] = $setLimitMax;
			$generateMeta['donation']['set_limit']['details'] = '';
			
			$generateMeta['donation']['set_add_fees']['enable'] = 'No';
			$generateMeta['donation']['set_add_fees']['fees_amount'] = 0;
			$generateMeta['donation']['set_add_fees']['fees_type'] = 'percentage';
			$generateMeta['donation']['set_add_fees']['fees_label'] = '';
			
			// step form design
			$generateMeta['form_design']['styles'] = 'all_fields';
			$generateMeta['form_design']['continue_button'] = 'Continue';
			$generateMeta['form_design']['submit_button'] = 'Donate Now';
			$generateMeta['form_design']['custom_class'] = '';
			$generateMeta['form_design']['custom_id'] = '';
			
			// form content
			$generateMeta['form_content']['enable'] = 'No';
			$generateMeta['form_content']['content_position'] = 'after-form';
			$generateMeta['form_content']['content'] = '';
			$generateMeta['form_content']['additional']['enable'] = 'Yes';
			$generateMeta['form_content']['additional']['dimentions'] = \WfpFundraising\Apps\Settings::default_addition_filed();
			
			// goal setup
			$metaDisplayKey = 'wfp_display_options_data';
			$getMetaDisplayOp = get_option( $metaDisplayKey );
			$formGoalData = isset($getMetaDisplayOp['goal_setup']) ? $getMetaDisplayOp['goal_setup'] : [ 'goal_type' => 'terget_goal', 'bar_style' => 'line_bar', 'backers' => 'Yes', 'bar_display_sty' => 'amount_show', 'bar_color' => '#007bff'];
			$formSettingData = isset($getMetaDisplayOp['form_settings']) ? $getMetaDisplayOp['form_settings'] : [];
		
			if( isset($meta_post['goal_setup']['goal_type']) && empty($meta_post['goal_setup']['goal_type']) ){
				$generateMeta['goal_setup'] = (object) $formGoalData;
			}else{
				$generateMeta['goal_setup']['enable'] = 'Yes';
				$generateMeta['goal_setup']['goal_type'] = isset($meta_post['goal_setup']['goal_type']) ? $meta_post['goal_setup']['goal_type'] : 'terget_goal';
				$generateMeta['goal_setup']['bar_style'] = isset($formGoalData['bar_style']) ? $formGoalData['bar_style'] : 'line_bar';
				$generateMeta['goal_setup']['bar_display_sty'] = isset($formGoalData['bar_display_sty']) ? $formGoalData['bar_display_sty'] : 'amount_show';
				$generateMeta['goal_setup']['bar_color'] = isset($formGoalData['bar_display_sty']) ? $formGoalData['bar_display_sty'] : '#007bff';
				$generateMeta['goal_setup']['terget'] = isset($meta_post['goal_setup']['terget']) ? $meta_post['goal_setup']['terget'] : [];
				
			}
			if(isset($meta_post['goal_setup']['terget']['message']) && strlen($meta_post['goal_setup']['terget']['message']) > 2){
				$generateMeta['goal_setup']['terget']['enable'] = 'Yes';	
			}
			// pledge setup
			$generateMeta['pledge_setup'] = isset($meta_post['pledge_setup']) ? $meta_post['pledge_setup'] : [];
			
			// form settings
			$generateMeta['form_settings'] = $formSettingData;
			if( isset($meta_post['form_settings']['contributor']['enable'])){
				$generateMeta['form_settings']['contributor']['enable'] = 'Yes';
			}
			if(isset($meta_post['form_settings']['single_review']['enable'])){
				$generateMeta['form_settings']['single_review']['enable'] = 'Yes';
			}
			if(isset($meta_post['form_settings']['single_updates']['enable'])){
				$generateMeta['form_settings']['single_updates']['enable'] = 'Yes';
			}
			// forms terms
			$generateMeta['form_terma'] = (object)[ 'enable' => 'No', 'content_position' => 'before-submit-button'];
			
			// form meta key
			$metaKey = 'wfp_form_options_meta_data';
			// meta post data modify. Save meta optins data 
			update_post_meta( $post_id, $metaKey, $generateMeta);
			
			// set new key type of form [donation or croudfounding]
			$metaKeyType = 'wfp_founding_form_format_type';
			$formatType = isset($generateMeta['donation']['format']) ? $generateMeta['donation']['format'] : 'crowdfunding';
			update_post_meta( $post_id, $metaKeyType, $formatType);
			
			// set user current post user update user
			$metaKeyUserUpdate = 'wfp_founding_form_update_user';
			$metaUserJson = get_post_meta( $post_id, $metaKeyUserUpdate, false );
			$metaUserJson = ['date' => time(), 'user' => get_current_user_id()];
			update_post_meta( $post_id, $metaKeyUserUpdate, $metaUserJson);
			
			

			//attatchment type
			if(isset($meta_post['attatch_type'])){
				if( $meta_post['attatch_type'] == 'image' ){
					
					if( 'POST' == $_SERVER['REQUEST_METHOD']  ) {
						$files = isset($_FILES["wfp_files_upload"]) ? $_FILES["wfp_files_upload"] : '';
						//if ( $_FILES ) { 
						if ( isset($files['name']) && sizeof($files['name']) > 0) { 
							$files = $_FILES["wfp_files_upload"]; 
							$check = isset($request['wfp_uploaded']) ? $request['wfp_uploaded'] : [];
							$newupload = [];	
							foreach ($files['name'] as $key => $value) {
								if ($files['name'][$key]) { 
									$file = [ 
										'name' => $files['name'][$key],
										'type' => $files['type'][$key], 
										'tmp_name' => $files['tmp_name'][$key], 
										'error' => $files['error'][$key],
										'size' => $files['size'][$key]
									]; 
									$_FILES = ["wfp_files_upload" => $file]; 
									foreach ($_FILES as $file => $array) {              
										$fileID = str_replace(' ', '_', $files['name'][$key]);
										if(in_array($fileID, $check)){
											$newupload1 = $this->my_handle_attachment($file, $post_id, true); 
											if($newupload1 > 0){
												$newupload[] = $newupload1;
											}
										}
									}
								} 
							}
							if(sizeof($newupload) > 1){
								update_post_meta( $post_id, 'wfp_portfolio_gallery', implode(',', $newupload) );
							}							
						}
					}
					
				}else if( $meta_post['attatch_type'] == 'video' ){
					$videoUrl = isset($meta_post['wfp_featured_video_url']) ? $meta_post['wfp_featured_video_url'] : '';
					update_post_meta( $post_id, 'wfp_featured_video_url', $videoUrl);
				}
				if(isset($request['wfp_uploaded_update'])){
					$updateImage = isset($request['wfp_uploaded_update']) ? $request['wfp_uploaded_update'] : [];
					update_post_meta( $post_id, '_thumbnail_id', end($updateImage) );
					update_post_meta( $post_id, 'wfp_portfolio_gallery', implode(',', $updateImage) );
				}
			}
			if($update_post > 0){
				$return['success'] = __('Successfully Update this Campaign.', 'wp-fundraising');
			}else{
				$return['success'] = __('Successfully Submitted Campaign for Review.', 'wp-fundraising');
			}
		}else{
			$return['error'] = __('Invalid Campaign.', 'wp-fundraising');
		}
		return $return;
		
	}
	
	public function my_handle_attachment($file_handler, $post_id, $set_thu=false) {
	  
	  if ($_FILES[$file_handler]['error'] !== UPLOAD_ERR_OK) __return_false();

	  require_once(ABSPATH . "wp-admin" . '/includes/image.php');
	  require_once(ABSPATH . "wp-admin" . '/includes/file.php');
	  require_once(ABSPATH . "wp-admin" . '/includes/media.php');

	  $attach_id = (int) media_handle_upload( $file_handler, $post_id );
	  if ( $set_thu ) {
		update_post_meta( $post_id, '_thumbnail_id', $attach_id );
	  }
	  return $attach_id;
	}
	
	/**
     * Donate wfp_action_rest_profile_submit_by_user .
     * Method Description: Profile form submit from Dashboard by the current user.
     * @since 1.0.0
     * @access for public
     */
	public function wfp_action_rest_profile_submit_by_user( \WP_REST_Request $request  ){
		$return = ['success' => [], 'error' => [] ];
		$error = false;
		$formId = isset($request['formid']) ? intval($request['formid']) : 0;
		
		$billing = (array) isset($request['billing_post']) ? Settings::sanitize($request['billing_post']) : [];
		
		$userId = get_current_user_id();
		if(empty($userId) || $userId == 0){
			$return['error'] = __('Something error.', 'wp-fundraising');
			return $return;
		}
		foreach( $billing as $k=>$v){
			// update user meta
			update_user_meta($userId, $k, $v);
		}
		
		$shipping = (array) isset($request['shipping_post']) ? Settings::sanitize($request['shipping_post']) : [];
		foreach( $shipping as $kk=>$vv){
			// update user meta
			update_user_meta($userId, $kk, $vv);
		}
		
		$return['success'] = __('Successfully Update your Information.', 'wp-fundraising');
		return $return;
	}
	/**
     * Donate wfp_action_rest_password_submit_by_user .
     * Method Description: user password modify
     * @since 1.0.0
     * @access for public
     */
	public function wfp_action_rest_password_submit_by_user( \WP_REST_Request $request  ){
		$return = ['success' => [], 'error' => [] ];
		$error = false;
		$formId = isset($request['formid']) ? Settings::sanitize($request['formid']) : 0;
		
		$userId = get_current_user_id();
		if($userId == 0 || $userId == ''){
			$return['error'] = __('Sorry you could not able to update password.', 'wp-fundraising');
			return $return;
		}
		
		$user_info = get_userdata($userId);
		$userPassword = isset($user_info->user_pass) ? $user_info->user_pass : '';
		
		$password = isset($request['password']) ? Settings::sanitize($request['password']) : [];
		
		$current = isset($password['current_pass']) ? Settings::sanitize($password['current_pass']) : '';
		
		$new = isset($password['new_pass']) ? Settings::sanitize($password['new_pass']) : '';
		
		$confirm = isset($password['confirm_pass']) ? Settings::sanitize($password['confirm_pass']) : '';
		
		if( strlen($current) > 2){
			if(wp_check_password($current , $userPassword, $userId)){
				if(strlen($new) > 5 && $new === $confirm){
					
					wp_set_password($new, $userId);
					
					$return['success'] = __('Successfully set new password.', 'wp-fundraising');
					
				}else{
					$return['error'] = __('Sorry don\'t match new password', 'wp-fundraising');
				}
			}else{
				$return['error'] = __('Sorry current don\'t match password', 'wp-fundraising');
			}
		}else{
			$return['error'] = __('Please enter current password.', 'wp-fundraising');
		}
		return $return;
	}
	/**
     * Donate wfp_action_rest_login_user .
     * Method Description: create new user
     * @since 1.0.0
     * @access for public
     */
	
	public function wfp_action_rest_login_user(  \WP_REST_Request $request  ){
		$return = ['success' => [], 'error' => [] ];
		$error = false;
		$formId = isset($request['formid']) ? intval($request['formid']) : 0;
		$wfp_login = isset($request['wfp_login']) ? Settings::sanitize($request['wfp_login']) : [];
		
		$userId = 0;
		
		if(is_user_logged_in()){
			$return['success'] = true;
		}else{	
			$username = isset($wfp_login['username']) ? $wfp_login['username'] : '';
			if( empty(trim($username)) ){
					$return['error'] = __('Please enter email or username', 'wp-fundraising');
				return $return;
			}
			
			$password = isset($wfp_login['username']) ? $wfp_login['password'] : '';
			if( empty(trim($password)) ){
					$return['error'] = __('Please enter password', 'wp-fundraising');
				return $return;
			}
			
			$creds = array(
				'user_login'    => $username,
				'user_password' => $password,
				'remember'      => isset($wfp_login['rememberme']) ? true : false
			);
		 
			$user = wp_signon( $creds, false );
			if ( is_wp_error( $user ) ) {
				$return['error'] =  $user->get_error_message();
			}else{
				$return['success'] = true;
			}
		}
		return $return;
		
	}
	
	/**
     * Donate wfp_action_rest_login_user .
     * Method Description: create new user
     * @since 1.0.0
     * @access for public
     */
	
	public function wfp_action_rest_register_user(  \WP_REST_Request $request  ){
		$return = ['success' => [], 'error' => [] ];
		$error = false;
		$formId = isset($request['formid']) ? intval($request['formid']) : 0;
		$wfp_register = isset($request['wfp_register']) ? Settings::sanitize($request['wfp_register']) : [];
		
		$userId = 0;
		
		if(is_user_logged_in()){
			$return['error'] = __('System Error', 'wp-fundraising');
		}else{	
			$email_address = isset($wfp_register['email']) ? $wfp_register['email'] : '';
			$username = isset($wfp_register['username']) ? $wfp_register['username'] : '';
			$password = isset($wfp_register['password']) ? $wfp_register['password'] : '';
			
			if(email_exists($email_address)){
				$userId = email_exists($email_address);
				$return['error'] = __('Already used this email', 'wp-fundraising');
			}else{
				if( empty(trim($email_address)) ){
					$return['error'] = __('Please enter email address', 'wp-fundraising');
					return $return;
				}
				if( empty(trim($username)) ){
					$return['error'] = __('Please enter your user name', 'wp-fundraising');
					return $return;
				}
				
				if( empty(trim($password)) ){
					$return['error'] = __('Please set your password', 'wp-fundraising');
					return $return;
				}
				
				$userdata = [];
				$userdata['user_nicename'] = $username;
				$userdata['display_name'] = $username;
				$userdata['user_email'] = $email_address;
				$userdata['user_login'] = current(explode('@', $email_address));
				$userdata['user_pass'] = $password;
				if( strlen($email_address) > 8 && \WfpFundraising\Apps\Settings::valid_email($email_address) ){
					$userId = wp_insert_user( $userdata ) ;
					if ( is_wp_error( $userId ) ) {
						$return['error'] = __('Sorry system error. Try again.', 'wp-fundraising');
					}else{
						
						$creds = array(
							'user_email'    => $email_address,
							'user_password' => $password,
							'remember'      => true
						);
					 
						$user = wp_signon( $creds, false );
						$return['success'] = true;
					}
					
				}else{
					$return['error'] = __('Please enter your valid email address', 'wp-fundraising');
				}
			}
		}
		return $return;
		
	}
	
	/**
     * Donate wfp_action_rest_user_review .
     * Method Description: post review for user only one review
     * @since 1.0.0
     * @access for public
     */
	public function wfp_action_rest_user_review( \WP_REST_Request $request  ){
		global $wpdb;
		
		$return = ['success' => [], 'error' => [] ];
		$error = false;
		$formId = isset($request['formid']) ? intval($request['formid']) : 0;
		
		$post = get_post($formId);
		
		if(!property_exists($post, 'ID') ){
			$return['error'] = __('Sorry invalid campaign.', 'wp-fundraising');
			return $return;
		}
		
		if(is_user_logged_in()){
			
			$wfp_review = isset($request['review_post']) ? Settings::sanitize($request['review_post']) : [];
			$name = isset($wfp_review['name']) ? $wfp_review['name'] : '';
			$email = isset($wfp_review['email']) ? $wfp_review['email'] : '';
			$ratting = isset($wfp_review['ratting']) ? (int) $wfp_review['ratting'] : 0;
			$summery = isset($wfp_review['summery']) ? $wfp_review['summery'] : '';
			$parent_id = isset($wfp_review['parent']) ? (int) $wfp_review['parent'] : 0;
			
			if( empty(trim($email)) ){
				$return['error'] = __('Please enter email address', 'wp-fundraising');
				return $return;
			}
			if( empty(trim($name)) ){
				$return['error'] = __('Please enter your name', 'wp-fundraising');
				return $return;
			}
			
			if( empty(trim($ratting)) ){
				$return['error'] = __('Please give your ratting', 'wp-fundraising');
				return $return;
			}
			
			$userId = get_current_user_id();
			
			// check post by title and post_author
			
			$postTitle = 'Wfp Review : '.$formId.'-'.$userId;
			$contentData = 'Name: '.$name.'<br/> Email: '.$email.' <br/> Ratting: '.$ratting.'<br/> Summery: '.$summery;
			
			/*Check update data*/
			if( $parent_id > 0 ){
				
				$post_p = get_post($parent_id);
		
				if(!property_exists($post_p, 'ID') ){
					$return['error'] = __('Sorry invalid review.', 'wp-fundraising');
					return $return;
				}
				
				$author_id = (property_exists($post_p, 'post_author')) ? (int) $post_p->post_author : 0;
				$post_type = (property_exists($post_p, 'post_type')) ? $post_p->post_type : '';
				
				$author_id_parent = (property_exists($post, 'post_author')) ? $post->post_author : 0;

				if($author_id != $userId AND $userId != $author_id_parent){
					$return['error'] = __('Sorry you are not valid user.', 'wp-fundraising');
					return $return;
				}
				//return $post_type;
				if( $post_type != 'wfp-review'){
					$return['error'] = __('Invalid Review.', 'wp-fundraising');
					return $return;
				}
				$update = [];
				$update['ID']     			= $parent_id;
				$update['post_content']    = $contentData;
				$update['post_title']      = $postTitle;
				if( wp_update_post($update) ){
					$metaKey = '__wfp_public_review_data';
					$metaDataJson = get_post_meta( $parent_id, $metaKey, true );
					$getMetaData = json_decode($metaDataJson, true);

					$meta_pa = [];
					$meta_pa['wfp_review_id'] = $formId;
					$meta_pa['wfp_user_id'] = $userId;
					$meta_pa['name'] = isset($getMetaData['name']) ? $getMetaData['name'] : '';
					$meta_pa['email'] = isset($getMetaData['email']) ? $getMetaData['email'] : '';
					$meta_pa['summery'] = $summery;
					$meta_pa['ratting'] = $ratting;
					$meta_pa['status'] = 'Publish';
					
					if(update_post_meta( $parent_id, $metaKey, json_encode($meta_pa) ) ){
						$return['success'] = __('Successfully updated review', 'wp-fundraising');
						return $return;
					}
				}else{
					$return['error'] = __('Sorry system error.', 'wp-fundraising');
					return $return;
				}
			}

			$query = $wpdb->prepare(
				'SELECT ID FROM ' . $wpdb->posts . '
				WHERE post_author = %s
				AND post_parent = %s
				AND post_type = \'wfp-review\'',
				$userId,
				$formId
			);
			$wpdb->query( $query );
			
			if ( $wpdb->num_rows ) {
				$return['error'] = __('Sorry already submitted review', 'wp-fundraising');
				return $return;
			}
			
			// submit post data
			$postarr = [];
			$postarr['post_author']     = $userId;
			$postarr['post_content']    = $contentData;
			$postarr['post_title']      = $postTitle;
			$postarr['post_parent']      = $formId;
			$postarr['post_status']     = 'publish';
			$postarr['post_type']       = 'wfp-review';
			
			$getPostId = (int) wp_insert_post($postarr);
			
			if(!empty($getPostId)){
				$metaKey = '__wfp_public_review_data';
				
				$meta_dat = [];
				$meta_dat['wfp_review_id'] = $formId;
				$meta_dat['wfp_user_id'] = $userId;
				$meta_dat['name'] = $name;
				$meta_dat['email'] = $email;
				$meta_dat['summery'] = $summery;
				$meta_dat['ratting'] = $ratting;
				$meta_dat['status'] = 'Publish';
				
				if(update_post_meta( $getPostId, $metaKey, json_encode($meta_dat) ) ){
					$return['success'] = __('Successfully submitted review', 'wp-fundraising');
					return $return;
				}
			}else{
				$return['error'] = __('System error', 'wp-fundraising');
				return $return;
			}
			
		}else{
			$return['error'] = __('Please sign in first', 'wp-fundraising');
			return $return;
		}
		
		return $return;
	}

	/**
     * Donate wfp_action_rest_review_delete .
     * Method Description: review delete by reviewer user
     * @since 1.0.0
     * @access for public
     */
	public function wfp_action_rest_review_delete( \WP_REST_Request $request ){
		$return = ['success' => [], 'error' => [] ];
		
		if(!is_user_logged_in()){
			$return['error'] = __('Sorry you are not valid author for delete review.', 'wp-fundraising');
			return $return;
		}
		
		$form_data = isset($request['params']) ? $request['params'] : '';
		$ex_form = explode('__', $form_data);
		$user_id = isset($ex_form[2]) ? $ex_form[2] : 0;
		$formId = isset($ex_form[1]) ? $ex_form[1] : 0;
		
		$post = get_post($formId);
		
		if(!property_exists($post, 'ID') ){
			$return['error'] = __('Sorry invalid review.', 'wp-fundraising');
			return $return;
		}
		
		$author_id = (property_exists($post, 'post_author')) ? (int) $post->post_author : 0;
		$post_type = (property_exists($post, 'post_type')) ? $post->post_type : '';
		
		$parentId = (property_exists($post, 'post_parent')) ? (int) $post->post_parent : 0;
		$post_parent = get_post($parentId);
		$author_id_parent = (property_exists($post_parent, 'post_author')) ? (int) $post_parent->post_author : 0;

		if($author_id != $user_id AND $user_id != $author_id_parent){
			$return['error'] = __('Sorry you are not valid user.', 'wp-fundraising');
			return $return;
		}

		if( $post_type != 'wfp-review'){
			$return['error'] = __('Invalid Review.', 'wp-fundraising');
			return $return;
		}

		if( wp_delete_post( $formId, true ) ){
			$return['success'] = __('Successfully remove your review.', 'wp-fundraising');
		}else{
			$return['error'] = __('System error.', 'wp-fundraising');
		}
		return $return;
	}
	
		/**
     * Donate wfp_action_rest_review_update .
     * Method Description: review update by reviewer user
     * @since 1.0.0
     * @access for public
     */
	public function wfp_action_rest_review_update( \WP_REST_Request $request ){
		$return = ['success' => [], 'error' => [] ];
		
		if(!is_user_logged_in()){
			$return['error'] = __('Sorry you are not valid author for delete review.', 'wp-fundraising');
			return $return;
		}
		
		$form_data = isset($request['params']) ? $request['params'] : '';
		$ex_form = explode('__', $form_data);
		$user_id = isset($ex_form[1]) ? $ex_form[1] : 0;
		$formId = isset($ex_form[0]) ? $ex_form[0] : 0;
		
		$post = get_post($formId);
		
		if(!property_exists($post, 'ID') ){
			$return['error'] = __('Sorry invalid review.', 'wp-fundraising');
			return $return;
		}
		
		$author_id = (property_exists($post, 'post_author')) ? (int) $post->post_author : 0;
		$post_type = (property_exists($post, 'post_type')) ? $post->post_type : '';
		
		$parentId = (property_exists($post, 'post_parent')) ? (int) $post->post_parent : 0;
		$post_parent = get_post($parentId);
		$author_id_parent = (property_exists($post_parent, 'post_author')) ? (int) $post_parent->post_author : 0;

		if($author_id != $user_id AND $user_id != $author_id_parent){
			$return['error'] = __('Sorry you are not valid user.', 'wp-fundraising');
			return $return;
		}

		if( $post_type != 'wfp-review'){
			$return['error'] = __('Invalid Review.', 'wp-fundraising');
			return $return;
		}
		$metaDataJson = get_post_meta( $formId, '__wfp_public_review_data', true );
		$getMetaData = json_decode($metaDataJson, true);

		$return['success']['parent'] =  $formId;
		$return['success']['ratting'] =  isset($getMetaData['ratting']) ? (int) $getMetaData['ratting'] : 0;
		$return['success']['name'] =  isset($getMetaData['name']) ? (string) $getMetaData['name'] : '';
		$return['success']['email'] =  isset($getMetaData['email']) ? (string) $getMetaData['email'] : '';
		$return['success']['summery'] =  isset($getMetaData['summery']) ? (string) $getMetaData['summery'] : '';

		return $return;
	}
	/**
     * Donate wfp_action_rest_user_update .
     * Method Description: post review for user only one review
     * @since 1.0.0
     * @access for public
     */
	public function wfp_action_rest_user_update( \WP_REST_Request $request  ){
		global $wpdb;
		
		$return = ['success' => [], 'error' => [] ];
		$error = false;
		$formId = isset($request['formid']) ? intval($request['formid']) : 0;
		
		$post = get_post($formId);
		
		if(!property_exists($post, 'ID') ){
			$return['error'] = __('Sorry invalid campaign.', 'wp-fundraising');
			return $return;
		}
		
		$userId = get_current_user_id();
		
		$author_id = (property_exists($post, 'post_author')) ? 	$post->post_author : 0;
		
		if( is_user_logged_in() && $userId == $author_id ){
			
			$wfp_review = isset($request['updates_post']) ? $request['updates_post'] : [];
			$update = isset($wfp_review['details']) ? $wfp_review['details'] : '';
			
			if( empty(trim($update))){
				$return['error'] = __('Please enter your update details.', 'wp-fundraising');
				return $return;
			}
			
			$postTitle = 'Wfp Update : '.$formId.'-'.date("Y-m-d H");
			
			// submit post data
			$postarr = [];
			$postarr['post_author']     = $userId;
			$postarr['post_content']    = $update;
			$postarr['post_title']      = $postTitle;
			$postarr['post_parent']      = $formId;
			$postarr['post_status']     = 'publish';
			$postarr['post_type']       = 'wfp-update';
			
			$getPostId = (int) wp_insert_post($postarr);
			
			if(!empty($getPostId)){
				$return['success'] = __('Successfully submitted update', 'wp-fundraising');
				return $return;
			}else{
				$return['error'] = __('System error', 'wp-fundraising');
				return $return;
			}
			
		}else{
			$return['error'] = __('Sorry invalid user for post campaign update.', 'wp-fundraising');
			return $return;
		}
		
		return $return;
	}
	
	
	/**
     * Donate wdp_donation_css_loader_front .
     * Method Description: load css files in front-end page
     * @since 1.0.0
     * @access for public
     */
	 public function wfp_donation_css_loader_public(){
		
		// repeater
		wp_enqueue_script( 'wfp_repeater_script' );
		// sortable
		wp_enqueue_script( 'jquery-ui-sort' );


		// get general page options data
		$metaGeneralKey = 'wfp_general_options_data';
		$getMetaGeneralOp = get_option( $metaGeneralKey );
		$getMetaGeneral = isset($getMetaGeneralOp['options']) ? $getMetaGeneralOp['options'] : [];
		$getMetaGeneralPage = isset($getMetaGeneral['pages']) ? $getMetaGeneral['pages'] : [];	
		
		$dashboardPage = isset($getMetaGeneralPage['dashboard']) ? $getMetaGeneralPage['dashboard'] : 'wfp-dashboard';
		$campaignPage = isset($getMetaGeneralPage['campaign']) ? $getMetaGeneralPage['campaign'] : 'wfp-campaign';
		$checkoutPage = isset($getMetaGeneralPage['checkout']) ? $getMetaGeneralPage['checkout'] : 'wfp-checkout';
		$successPage = isset($getMetaGeneralPage['success']) ? $getMetaGeneralPage['success'] : 'wfp-success';
		
		
		// donation admin css
		wp_enqueue_style( 'wfp_donation_admin_css' );
		
		// front-end css 
        wp_enqueue_style( 'wfp_donation_public_css' ); 
		
		// fonts
		wp_enqueue_style( 'wfp_fonts' );
		
		wp_enqueue_style( 'wfp_met-fonts' );
		
		if(is_page($dashboardPage)  || $campaignPage == 'wfp-dashboard'){
			// dashboard css
			wp_enqueue_style( 'wfp_dashboard_css' );
			
			// login css
			wp_enqueue_style( 'wfp_login_css' );
		 
		}
		
		if( is_page($campaignPage) || $campaignPage == 'wfp-campaign'){
			//list campaign css
			wp_enqueue_style( 'wfp_single_campaign_css' );
		}
		//single page css
		wp_enqueue_style( 'wfp_single_css' );
		
		// global laibray
		wp_enqueue_style( 'wfp_css_libarey' );
		
		// mater css
        wp_enqueue_style( 'wfp_css_master' );
		
		if( is_page($checkoutPage)  || $checkoutPage == 'wfp-checkout' || is($successPage) || $successPage == 'wfp-success'){
			// checkout css
			wp_enqueue_style( 'wfp_css_checkout' );
		}

		

		//main js for front-end
		wp_enqueue_script( 'wfp_donation_form_script' );
		wp_localize_script('wfp_donation_form_script', 'xs_donate_url', array( 'siteurl' => get_option('siteurl'), 'nonce' => wp_create_nonce( 'wp_rest' ), 'resturl' => get_rest_url() ));
		
		if(is_page($dashboardPage) || $campaignPage == 'wfp-dashboard'){	
			// form js laibray
			wp_enqueue_script( 'wfp_campaign_form_step' );
			wp_localize_script('wfp_campaign_form_step', 'xs_donate_url', array( 'siteurl' => get_option('siteurl'), 'nonce' => wp_create_nonce( 'wp_rest' ), 'resturl' => get_rest_url()) );
			
			// dashboard
			wp_enqueue_script( 'wfp_dashboard_script' );
			wp_localize_script('wfp_dashboard_script', 'xs_donate_url', array( 'siteurl' => get_option('siteurl'), 'nonce' => wp_create_nonce( 'wp_rest' ), 'resturl' => get_rest_url() ));
			
			// login js
			 wp_enqueue_script( 'wfp_login_script' );
			 wp_localize_script('wfp_login_script', 'xs_donate_url', array( 'siteurl' => get_option('siteurl'), 'nonce' => wp_create_nonce( 'wp_rest' ), 'resturl' => get_rest_url() ));
			
			 // chart js
			wp_enqueue_script( 'chartjs' );
			
		}

		if(is_single()){
			// magnific popup js
			wp_enqueue_script( 'magnific_js' );

			// single js
			wp_enqueue_script( 'wfp_single_script' );
			wp_localize_script('wfp_single_script', 'xs_donate_url', array( 'siteurl' => get_option('siteurl'), 'nonce' => wp_create_nonce( 'wp_rest' ), 'resturl' => get_rest_url() ) );
			
		}
		
		
		wp_enqueue_script('wfp_easy_pie_script');
       
		// stripe checkout script 
		wp_enqueue_script( 'wfp_stripe_checkout_js' );

		// responsive css
		 wp_enqueue_style( 'wfp_responsive_css_master' );
		
	 }
	
	/**
     * Donate wfp_fund_donation_shortcode.
     * Method Description: Short-code options
     * @since 1.0.0
     * @access public
     */
	 public function wfp_fund_donation_shortcode(  $atts , $content = null ){
		// create shortcode
		$atts = shortcode_atts(
				[
					'form-id' => 0,
					'form-style' => '',
					'modal' => '',
					'class' => '',
					'id' => '',
					'format-style' => '',
					'goal' => 'Yes',
					'user' => 'Yes',
					'category' => 'Yes',
					'title' => 'Yes',
					'featured' => 'Yes',
				], $atts, 'wfp-forms' 
		);
		
		$postId 	 	 =  isset($atts['form-id']) ? $atts['form-id'] : 0;
		
		if($postId > 0){
			$post = get_post($postId);
			if( is_object($post)){
				$this->additionalCss = $postId;
				return $this->wfp_fund_donation_form_display($post, $atts);
			}
		}
		
	 }
	 
	 /**
     * Donate wfp_fund_donation_form_display.
     * Method Description: Display donation forms
     * @since 1.0.0
     * @access public
     */
	 public function wfp_fund_donation_form_display( object $post, $atts = [], $format_style='' ){
		 if(!isset($post->ID)){
			 return '';
		 }
		 $getPostTYpe = $post->post_type;
		
		 $arrayPayment = xs_payment_services();
		
		// require file
		if($getPostTYpe == self::post_type()){
			// get post meta data 
			$metaKey = 'wfp_form_options_meta_data';
			$metaDataJson = get_post_meta( $post->ID, $metaKey, false );
			$getMetaData = json_decode(json_encode(end($metaDataJson)));
			
			// get option for payment gateways
			$optinsKey = 'wfp_payment_options_data';
			$getOptionsData = get_option( $optinsKey );
			$gateWaysData = isset($getOptionsData['gateways']) ? $getOptionsData['gateways'] : [];
			
			// start object data options
			ob_start();
			include( WFP_FUNDRAISING_PLUGIN_PATH.'views/public/donation/donation-display-form.php' );
			$getContent = ob_get_contents();
			ob_end_clean();
			// end object data
			return $getContent;
		}
		
	 }
	 
	 /**
     * Donate wfp_content_replace_for_success_page.
     * Method Description: Content replace for dashboard page
     * @since 1.0.0
     * @access public
     */
	 public function wfp_content_replace_for_dashboard_page( $content ){
		$metaGeneralKey = 'wfp_general_options_data';
		$getMetaGeneralOp = get_option( $metaGeneralKey );
		$getMetaGeneral = isset($getMetaGeneralOp['options']) ? $getMetaGeneralOp['options'] : [];
		$getMetaGeneralPage = isset($getMetaGeneral['pages']) ? $getMetaGeneral['pages'] : [];	
		
		$dashboardPage = isset($getMetaGeneralPage['dashboard']) ? $getMetaGeneralPage['dashboard'] : 'wfp-dashboard';
		if($dashboardPage != 'wfp-dashboard'){
			if ( strcmp( $dashboardPage, get_post_field( 'post_name' ) ) === 0 ) {
				if (! preg_match('/\[wfp-dashboard\b/', $content) ) {
					$content .= '[wfp-dashboard]';
				}
			}
		}
		return $content;
	 }
	 /**
     * Donate wfp_content_replace_for_campaign_page.
     * Method Description: Content replace for campaign page
     * @since 1.0.0
     * @access public
     */
	 public function wfp_content_replace_for_campaign_page( $content ){
		$metaGeneralKey = 'wfp_general_options_data';
		$getMetaGeneralOp = get_option( $metaGeneralKey );
		$getMetaGeneral = isset($getMetaGeneralOp['options']) ? $getMetaGeneralOp['options'] : [];
		$getMetaGeneralPage = isset($getMetaGeneral['pages']) ? $getMetaGeneral['pages'] : [];	
		
		$campaignPage = isset($getMetaGeneralPage['campaign']) ? $getMetaGeneralPage['campaign'] : 'wfp-campaign';
		if($campaignPage != 'wfp-campaign'){
			if ( strcmp( $campaignPage, get_post_field( 'post_name' ) ) === 0 ) {
				if (! preg_match('/\[wfp-campaign\b/', $content) ) {
					$content .= '[wfp-campaign]';
				}
			}
		}
		return $content;
	 }
	  /**
     * Donate wfp_content_replace_for_checkout_page.
     * Method Description: Content replace for checkout page
     * @since 1.0.0
     * @access public
     */
	 public function wfp_content_replace_for_checkout_page( $content ){
		$metaGeneralKey = 'wfp_general_options_data';
		$getMetaGeneralOp = get_option( $metaGeneralKey );
		$getMetaGeneral = isset($getMetaGeneralOp['options']) ? $getMetaGeneralOp['options'] : [];
		$getMetaGeneralPage = isset($getMetaGeneral['pages']) ? $getMetaGeneral['pages'] : [];	
		
		// get payment type from options data
		$metaSetupKey = 'wfp_setup_services_data';
		$getSetUpData =  get_option( $metaSetupKey );
		$paymentType = isset($getMetaData['services']['payment']) ? $getMetaData['services']['payment'] : 'default';
		
		$dashboardPage = isset($getMetaGeneralPage['checkout']) ? $getMetaGeneralPage['checkout'] : 'wfp-checkout';
		
		if($paymentType == 'woocommerce'){
			//$shortCode = '[woocommerce_checkout]';
			if($dashboardPage != 'checkout'){
				if ( strcmp( $dashboardPage, get_post_field( 'post_name' ) ) === 0 ) {
					//if (! preg_match('/\[wfp-checkout\b/', $content) ) {
						$content .= '[woocommerce_checkout]';
					//}
				}
			}
		}else{
			if($dashboardPage != 'wfp-checkout'){
				if ( strcmp( $dashboardPage, get_post_field( 'post_name' ) ) === 0 ) {
					if (! preg_match('/\[wfp-checkout\b/', $content) ) {
						$content .= '[wfp-checkout]';
					}
				}
			}	
		}
		
			
		return $content;
	 }
	 /**
     * Donate wfp_dashboard_content_shortcode.
     * Method Description: Shortcode action for dashboard page.
     * @since 1.0.0
     * @access public
     */
	 public function wfp_dashboard_content_shortcode(  $atts , $content = null ){
		
		// create shortcode
		$atts = shortcode_atts(
				[
					'class' => '',
					'id' => 'wfp-dashboard',
				], $atts, 'wfp-dashboard' 
		);
		$className 	 	 =  isset($atts['class']) ? $atts['class'] : '';
		$idName 	 	 =  isset($atts['id']) ? $atts['id'] : 'wfp-dashboard';
		
		$getPage = isset($_GET['page']) ? Settings::sanitize($_GET['page']) : 'dashboard';
		
		if( !is_user_logged_in() ){
			/*@ob_flush();
			@ob_end_flush();
			@ob_end_clean();
			wp_redirect( wp_login_url() );
			exit();*/
		}
		
		ob_start();
		if(is_user_logged_in()){
			include( WFP_FUNDRAISING_PLUGIN_PATH.'views/public/fundraising/dynamic-page/dashboard.php' );
		}else{
		
			include( WFP_FUNDRAISING_PLUGIN_PATH.'views/public/fundraising/dynamic-page/login.php' );
		}
		$content = ob_get_contents();
		ob_end_clean();
		
		return $content;
	 }
	
	 
	 /**
     * Donate wfp_success_content_shortcode.
     * Method Description: Shortcode action for success page.
     * @since 1.0.0
     * @access public
     */
	 public function wfp_success_content_shortcode(  $atts , $content = null ){
		 // create shortcode
		$atts = shortcode_atts(
				[
					'class' => '',
					'id' => 'wfp-success',
				], $atts, 'wfp-success' 
		);
		$className 	 	 =  isset($atts['class']) ? $atts['class'] : '';
		$idName 	 	 =  isset($atts['id']) ? $atts['id'] : 'wfp-success';
		// start object content
		ob_start();
		include( WFP_FUNDRAISING_PLUGIN_PATH.'views/public/fundraising/dynamic-page/success.php' );
		
		
		/*currency information*/
		$metaGeneralKey = 'wfp_general_options_data';
		$getMetaGeneralOp = get_option( $metaGeneralKey );
		$getMetaGeneral = isset($getMetaGeneralOp['options']) ? $getMetaGeneralOp['options'] : [];
		$defaultUse_space = isset($getMetaGeneral['currency']['use_space']) ? $getMetaGeneral['currency']['use_space'] : 'off';
		
		$getPaymentId = isset($_GET['target']) ? intval($_GET['target']) : 0;
		$getPaymentOrder = isset($_GET['token']) ? str_rot13(Settings::sanitize($_GET['token'])) : '';
		$post = get_post($getPaymentId);
		
		$returnkey = isset($_GET['key']) ? str_rot13(intval($_GET['key'])) : 0;
		$whereQuery = '';
		$whereQuery .= " AND donate_id = '".$returnkey."' AND invoice = '".$getPaymentOrder."' AND status IN('Active', 'Review')";
		$whereQuery .= " GROUP BY (invoice) ORDER BY donate_id DESC"; 
		$info = $this->wfp_get_result('', $whereQuery);
		$info = current($info);
		$orderId = isset($info->donate_id) ? $info->donate_id : 0;
		
		include( WFP_FUNDRAISING_PLUGIN_PATH.'views/public/fundraising/dynamic-page/order-confirm.php' );
		
		$content = ob_get_contents();

		ob_end_clean();
		
		return $content;
	 }
	 
	 /**
     * Donate wfp_checkout_content_shortcode.
     * Method Description: Shortcode action for checkout page.
     * @since 1.0.0
     * @access public
     */
	 public function wfp_checkout_content_shortcode(  $atts , $content = null ){
		 // create shortcode
		$atts = shortcode_atts(
				[
					'class' => '',
					'id' => 'wfp-checkout',
				], $atts, 'wfp-checkout' 
		);
		$className 	 	 =  isset($atts['class']) ? $atts['class'] : '';
		$idName 	 	 =  isset($atts['id']) ? $atts['id'] : 'wfp-checkout';
		
		/*currency information*/
		$metaGeneralKey = 'wfp_general_options_data';
		$getMetaGeneralOp = get_option( $metaGeneralKey );
		$getMetaGeneral = isset($getMetaGeneralOp['options']) ? $getMetaGeneralOp['options'] : [];
		$defaultUse_space = isset($getMetaGeneral['currency']['use_space']) ? $getMetaGeneral['currency']['use_space'] : 'off';
		
		// start object content data
		ob_start();
		if( isset($_GET['wfpout'])){
			$getPaymentId = isset($_GET['target']) ? intval($_GET['target']) : 0;
			$post = get_post($getPaymentId);
			
			$arrayPayment = xs_payment_services();
			
			// get post meta data 
			$metaKey = 'wfp_form_options_meta_data';
			$metaDataJson = get_post_meta( $post->ID, $metaKey, false );
			$getMetaData = json_decode(json_encode(end($metaDataJson)));
			
			// get option for payment gateways
			$optinsKey = 'wfp_payment_options_data';
			$getOptionsData = get_option( $optinsKey );
			$gateWaysData = isset($getOptionsData['gateways']) ? $getOptionsData['gateways'] : [];
			
			
			include( WFP_FUNDRAISING_PLUGIN_PATH.'views/public/fundraising/dynamic-page/checkout.php' );
			
		}else if(isset($_GET['wfporder'])){
			$getPaymentId = isset($_GET['target']) ? intval($_GET['target']) : 0;
			$getPaymentOrder = isset($_GET['id-order']) ? str_rot13(Settings::sanitize($_GET['id-order'])) : '';
			$post = get_post($getPaymentId);
			
			$whereQuery = '';
			$whereQuery .= " AND form_id = '".$getPaymentId."' AND invoice = '".$getPaymentOrder."' AND status IN('Active', 'Review')";
			$whereQuery .= " GROUP BY (invoice) ORDER BY donate_id DESC"; 
			$info = $this->wfp_get_result('', $whereQuery);
			$info = current($info);
			$orderId = isset($info->donate_id) ? $info->donate_id : 0;
			
			include( WFP_FUNDRAISING_PLUGIN_PATH.'views/public/fundraising/dynamic-page/order-confirm.php' );
		}
		$contentData = ob_get_contents();
		ob_end_clean();
		// end object content
		return $contentData;
	 }
	 
	 /**
     * Donate wfp_cancel_content_shortcode.
     * Method Description: Shortcode action for cancel page.
     * @since 1.0.0
     * @access public
     */
	 public function wfp_cancel_content_shortcode(  $atts , $content = null ){
		 // create shortcode
		$atts = shortcode_atts(
				[
					'class' => '',
					'id' => 'wfp-cancel',
				], $atts, 'wfp-cancel' 
		);
		$className 	 	 =  isset($atts['class']) ? $atts['class'] : '';
		$idName 	 	 =  isset($atts['id']) ? $atts['id'] : 'wfp-cancel';
		
		// start object content data
		ob_start();
		include( WFP_FUNDRAISING_PLUGIN_PATH.'views/public/fundraising/dynamic-page/cancel.php' );
		$content = ob_get_contents();
		ob_end_clean();
		// end object content data
		
		return $content;
	 }
	
	/**
     * Donate wfp_cancel_campaign_shortcode.
     * Method Description: Shortcode action for cancel page.
     * @since 1.0.0
     * @access public
     */
	 public function wfp_list_campaign_shortcode(  $atts , $content = null ){
		 // create shortcode
		$atts = shortcode_atts(
				[
					'class' => '',
					'id' => 'wfp-campaign',
					'layout' => 'grid',
					'column' => '3',
					'limit' => 9,
					'orderby' => 'post_date',
					'order' => 'DESC',
					'categories' => '',
					'goal' => 'Yes',
					'user' => 'Yes',
					'category' => 'Yes',
					'title' => 'Yes',
					'excerpt' => 'Yes',
					'featured' => 'Yes',
				], $atts, 'wfp-campaign' 
		);
		$className 	 	 =  isset($atts['class']) ? $atts['class'] : '';
		$idName 	 	 =  isset($atts['id']) ? $atts['id'] : 'wfp-campaign';
		$layout			 = isset($atts['layout']) ? $atts['layout'] : 'grid';
		$column			 = isset($atts['column']) ? $atts['column'] : '3';
		$wfp_fundraising_content__show_post	= isset($atts['limit']) ? $atts['limit'] : 9;
		$wfp_fundraising_content__orderby	= isset($atts['orderby']) ? $atts['orderby'] : 'post_date';
		$wfp_fundraising_content__order	= isset($atts['order']) ? $atts['order'] : 'DESC';
		$wfp_fundraising_content__goal_enable	= isset($atts['goal']) ? $atts['goal'] : 'Yes';
		$wfp_fundraising_content__user_enable	= isset($atts['user']) ? $atts['user'] : 'Yes';
		$wfp_fundraising_content__category_enable	= isset($atts['category']) ? $atts['category'] : 'Yes';
		$wfp_fundraising_content__title_enable	= isset($atts['title']) ? $atts['title'] : 'Yes';
		$wfp_fundraising_content__excerpt_enable	= isset($atts['excerpt']) ? $atts['excerpt'] : 'Yes';
		$wfp_fundraising_content__featured_enable	= isset($atts['featured']) ? $atts['featured'] : 'Yes';

		// categories
		if( !empty($atts['categories']) ){
			$wfp_fundraising_content__categories = explode(',', $atts['categories']);
		}
	

		// layout style
		if( $layout == 'list' ){
			$wfp_fundraising_content__layout_style = 'wfp-layout-list';
		}else if( $layout == 'masonary' ){
			$wfp_fundraising_content__layout_style = 'wfp-layout-masonary';
		}else{
			$wfp_fundraising_content__layout_style = 'wfp-layout-grid';
		}

		// column select
		if($column == '4'){
			$wfp_fundraising_content__column_grid = 'xs-col-lg-3';
		}else if($column == '2'){
			$wfp_fundraising_content__column_grid = 'xs-col-lg-6';
		}else{
			$wfp_fundraising_content__column_grid = 'xs-col-lg-4';
		}

		include(WFP_FUNDRAISING_PLUGIN_PATH.'country-module/country-info.php' );
		/*currency information*/
		$metaGeneralKey = 'wfp_general_options_data';
		$getMetaGeneralOp = get_option( $metaGeneralKey );
		$getMetaGeneral = isset($getMetaGeneralOp['options']) ? $getMetaGeneralOp['options'] : [];

		$defaultCurrencyInfo = isset($getMetaGeneral['currency']['name']) ? $getMetaGeneral['currency']['name'] : 'US-USD';
		$explCurr = explode('-', $defaultCurrencyInfo);
		$currCode = isset($explCurr[1]) ? $explCurr[1] : 'USD';
		$symbols = isset($countryList[current($explCurr)]['currency']['symbol']) ? $countryList[current($explCurr)]['currency']['symbol'] : '';
		$symbols = strlen($symbols) > 0 ? $symbols : $currCode;

		$defaultUse_space = isset($getMetaGeneral['currency']['use_space']) ? $getMetaGeneral['currency']['use_space'] : 'off';

		// start object content data
		ob_start();
		include( WFP_FUNDRAISING_PLUGIN_PATH.'views/public/fundraising/dynamic-page/campaign.php' );
		$content = ob_get_contents();
		ob_end_clean();
		
		return $content;
	 }
	
	/*
	* Added menu in manu bar for dashboard page
	*/
	public function wfp_add_dashboard_page_menu($items, $args){
		 //print_r($items);
		 if( $args->theme_location == 'primary' ){
			
			// page setup data
			if (is_user_logged_in()) {
				$metaGeneralKey = 'wfp_general_options_data';
				$getMetaGeneralOp = get_option( $metaGeneralKey );
				$getMetaGeneral = isset($getMetaGeneralOp['options']) ? $getMetaGeneralOp['options'] : [];
				
				$dashboardPage = isset($getMetaGeneralPage['dashboard']) ? $getMetaGeneralPage['dashboard'] : 'wfp-dashboard';
				
				$items .= '<li class="menu-item wfp-main-manu" id="wfp-dashboard-menu"><a href="' . home_url( '/' ).$dashboardPage.'/"> ' . __('Dahsboard', 'wp-fundraising') . '</a></li>';
				
				$items .= '<li class="menu-item wfp-main-manu" id="wfp-sign-out-menu"><a href="'. wp_logout_url() .'">' . __('Sign Out', 'wp-fundraising') . '</a></li>';
			}else{
				$items .= '<li class="menu-item wfp-main-manu" id="wfp-login-menu"><a href="'. wp_login_url() .'">' . __('Login', 'wp-fundraising') . '</a></li>';
				$items .= '<li class="menu-item wfp-main-manu" id="wfp-register-menu"><a href="'. wp_registration_url() .'">' . __('Register', 'wp-fundraising') . '</a></li>';
			}
         }
        return $items;
	}
	
	
	/**
	* Query Method 
	*/
	public function wfp_get_result($tableName = '', $queryData = ''){
		$tableName = self::wfp_donate_table($tableName);
		global $wpdb;
		$myrows = $wpdb->get_results( "SELECT * FROM `$tableName` WHERE 1 = 1 $queryData" );
		return $myrows;
		
	}
	
	public function wfp_get_sum($tableName = '', $sumFied= '', $queryData = ''){
		$tableName = self::wfp_donate_table($tableName);
		global $wpdb;
		$myrows = $wpdb->get_var( "SELECT SUM($sumFied) FROM `$tableName` WHERE 1 = 1 $queryData" );
		return $myrows;
	}
	public function wfp_get_count($tableName = '', $sumFied= '*', $queryData = ''){
		$tableName = self::wfp_donate_table($tableName);
		global $wpdb;
		$myrows = $wpdb->get_var( "SELECT COUNT($sumFied) FROM `$tableName` WHERE 1 = 1 $queryData" );
		return $myrows;
	}
	
	public function wfp_update_meta($post_id = 0, $meta_key = '', $meta_value = '', $unique = true){
		$tableNameMeta = self::wfp_donate_table('wdp_fundraising_meta');
		
		return \WfpFundraising\Apps\Settings::wfp_update_metadata($tableNameMeta, $post_id, $meta_key, $meta_value, $unique);
	}
	public function wfp_get_meta($post_id = 0, $meta_key = ''){
		$tableNameMeta = self::wfp_donate_table('wdp_fundraising_meta');
		return \WfpFundraising\Apps\Settings::wfp_get_metadata($tableNameMeta, $post_id, $meta_key);
	}
	
	public static function instance(){
        if (!self::$instance){
            self::$instance = new self();
        }
        return self::$instance;
    }
}	 
?>