<?php
namespace WfpFundraising\Apps;
if ( ! defined( 'ABSPATH' ) ) die( 'Forbidden' );
/**
 * Class Name : Settings - This access for admin
 * Class Type : Normal class
 *
 * initiate all necessary classes, hooks, configs
 *
 * @since 1.0.0
 * @access Public
 */
Class Settings{
	
	// declare custom post type here
	
	 const post_type = 'wp-fundraising';
	 
    /**
     * Construct the Settings object
     * @since 1.0.0
     * @access public
     */
	 
	 public $donate;
	 public $crowdfunding;
	 
	 private static $instance;
	 
     public function _init( $load = true){
	   if( $load ){
			
			add_action('init', [ $this, 'wfp_init_rest_welcome' ]); 
			

			// Remove editor function - Filter
			add_filter('user_can_richedit', [ $this, 'wfp_remove_visual_editor_donate' ]);

		   // Remove add media function - Action
			//add_action('admin_head', [ $this, 'wfp_remove_media_button_donate' ] );

			// Load css file / script for settings page
			add_action( 'admin_enqueue_scripts', [$this, 'wfp_settings_css_loader' ] );
			add_action( 'wp_enqueue_scripts', [$this, 'wfp_settings_css_loader' ] );

			add_filter( 'gettext', [$this, 'wfp_excerpt_modify'], 10, 2 );
			
			
			
			// get manu lst page
			//add_filter('wp_get_nav_menu_items', [ $this, 'wfp_add_dashboard_get_page_menu'], 20, 2);
			//add_action( 'init', [ $this, 'wfp_custom_nav_menu'] );
	   }
     }
	 
	  /**
     * Custom Post type : static method
     * @since 1.0.0
     * @access public
     */
	 private static function post_type(){
		 return self::post_type;
	 }
	 
	 public function wfp_excerpt_modify( $translation, $original )
	{
		if ( 'Excerpt' == $original ) {
			return 'Short Brief';
		}else{
			$pos = strpos($original, 'Excerpts are optional hand-crafted summaries of your');
			if ($pos !== false) {
				return  'Tell something about your campaign.';
			}
		}
		return $translation;
	}
	/**
     * Donate wfp_remove_visual_editor_donate
     * Method Description: remove visual editor from wordpress editor.
     * @since 1.0.0
     * @access public
     */
	public function wfp_remove_visual_editor_donate($default){
		global $post;
		if (self::post_type() == get_post_type($post))
			return true;
		return $default;
	}
	/**
     * Donate wfp_remove_media_button_donate 
     * Method Description: remove add media button from wordpress editor.
     * @since 1.0.0
     * @access public
     */
	public function wfp_remove_media_button_donate() {
		global $current_screen;
		// remove add media button from my post type	
		if( self::post_type() == $current_screen->post_type ){ 
			remove_action( 'media_buttons' , 'media_buttons' );
		}
	}
    /**
     * Donate wfp_init_rest_welcome .
     * Method Description: load rest api
     * @since 1.0.0
     * @access for public
     */ 
	 public function wfp_init_rest_welcome(){
		add_action( 'rest_api_init', function () {
		  register_rest_route( 'xs-welcome-form', '/welcome-submit/(?P<formid>\w+)/', 
			array(
				'methods' => 'GET',
				'callback' => [$this, 'wfp_action_rest_welcome_submit'],
			  ) 
		  );
		} );
		
    }
	
	/*
	* Get page list
	*/
	public function wfp_add_dashboard_get_page_menu($items, $args){
		//echo '<pre>'; print_r($items); echo '</pre>';
		 if( $args->theme_location == 'primary' ){
			 
		 }
		 return $items;
	}
	
	/*
	* WP Fundraising Custom nav menu bar
	*/
	public function wfp_custom_nav_menu() {
	  register_nav_menu('wp-fundraising-dashboard',__( 'Fundraising Dashboard' ));
	 /* wp_nav_menu( array( 
		'theme_location' => 'wp-fundraising-dashboard', 
		'container_class' => 'wfp-fundraising-dashboard' ) );*/
	}
	
	/**
     * Donate wfp_action_rest_welcome_submit .
     * Method Description: Action donate form submit when click this donate button.
     * @since 1.0.0
     * @access for public
     */ 
	public function wfp_action_rest_welcome_submit(\WP_REST_Request $request ){
		$return = ['success' => [], 'error' => [] ];
		$error = false;
		
		$getPath = isset($request['formid']) ? $request['formid'] : 'welcome';
		$data = isset($request['xs_welcome_data_submit']) ? \WfpFundraising\Apps\Settings::sanitize($request['xs_welcome_data_submit']) : [];
		$data['services']['finish'] = $getPath;
		
		$url = '';
		$metaSetupKey = 'wfp_setup_services_data';
		if( update_option($metaSetupKey, $data) ){
			$return['success'] = ['message' => 'Successfully Setup', 'finish_url' => $url];
		}
		
		return $return;
	}
    /**
     * Method: wfp_settings_css_loader .
     * Method Description: Settings Css Loader
     * @since 1.0.0
     * @access public
     */
     public function wfp_settings_css_loader(){
       
		// 3th party script & css
		
		// flatpickr date picker
		wp_register_style( 'flatpickr-wfp', WFP_FUNDRAISING_PLUGIN_URL. 'assets/flatpickr/flatpickr.min.css', false, WFP_FUNDRAISING_VERSION );
		wp_register_script( 'flatpickr-wfp', WFP_FUNDRAISING_PLUGIN_URL. 'assets/flatpickr/flatpickr.js', array( 'jquery' ), WFP_FUNDRAISING_VERSION, false);
		// select 2
		wp_register_style( 'select2', WFP_FUNDRAISING_PLUGIN_URL. 'assets/select2/css/select2-min.css', false, WFP_FUNDRAISING_VERSION );
		wp_register_script( 'select2', WFP_FUNDRAISING_PLUGIN_URL. 'assets/select2/script/select2-min.js', array( 'jquery' ), WFP_FUNDRAISING_VERSION, false );
		// repeater
		wp_register_script( 'wfp_repeater_script', WFP_FUNDRAISING_PLUGIN_URL.'assets/admin/script/jquery.form-repeater.js', array('jquery'), WFP_FUNDRAISING_VERSION, false );
      

		// commomn load

		// payment style
		wp_register_style( 'wfp_payment_css', WFP_FUNDRAISING_PLUGIN_URL. 'payment-module/assets/css/payment-style.css', false, WFP_FUNDRAISING_VERSION );
		// modal script
		wp_register_script( 'wfp_payment_script', WFP_FUNDRAISING_PLUGIN_URL. 'payment-module/assets/script/payment-script.js', array('jquery'), WFP_FUNDRAISING_VERSION, false );
         // sortable drag wfp_sortable_script
		//wp_register_script( 'jquery-ui-sort', WFP_FUNDRAISING_PLUGIN_URL. 'payment-module/assets/script/sortable-drag-script.js', array('jquery'), WFP_FUNDRAISING_VERSION, false);
		// payment modal script
		wp_register_script( 'wfp_payment_script_modal', WFP_FUNDRAISING_PLUGIN_URL. 'payment-module/assets/script/modal-js/modal-popup.js', WFP_FUNDRAISING_VERSION, false);
       

		 // admin load
		// settings css
		wp_register_style( 'wfp_settings_admin_css', WFP_FUNDRAISING_PLUGIN_URL. 'assets/admin/css/settings/settings.css', false, WFP_FUNDRAISING_VERSION );
		// Donation css
		wp_register_style( 'wfp_donation_admin_css', WFP_FUNDRAISING_PLUGIN_URL. 'assets/admin/css/donate/donation-form.css', false, WFP_FUNDRAISING_VERSION );
		// Donation Script
		wp_register_script( 'wfp_donation_admin_script', WFP_FUNDRAISING_PLUGIN_URL. 'assets/admin/script/donate/donate-form.js', array('jquery'), WFP_FUNDRAISING_VERSION, false );
		// main js
		wp_register_script( 'wfp_admin_main_script', WFP_FUNDRAISING_PLUGIN_URL. 'assets/admin/script/settings/main.js', array('jquery'), WFP_FUNDRAISING_VERSION, false );
	   


		// public load

		// donation public form
		wp_register_style( 'wfp_donation_public_css', WFP_FUNDRAISING_PLUGIN_URL. 'assets/public/css/donate/display-form-styles.css', false, WFP_FUNDRAISING_VERSION );
		// font wfp
		wp_register_style( 'wfp_fonts', WFP_FUNDRAISING_PLUGIN_URL. 'assets/public/css/fonts.css', false, WFP_FUNDRAISING_VERSION );
		// met font wfp
		wp_register_style( 'wfp_met-fonts', WFP_FUNDRAISING_PLUGIN_URL. 'assets/public/css/met-social.css', false, WFP_FUNDRAISING_VERSION );
		// dashboard css
		wp_register_style( 'wfp_dashboard_css', WFP_FUNDRAISING_PLUGIN_URL. 'assets/public/css/donate/dashboard.css', false, WFP_FUNDRAISING_VERSION );
		// login css
		wp_register_style( 'wfp_login_css', WFP_FUNDRAISING_PLUGIN_URL. 'assets/public/css/donate/login.css', false, WFP_FUNDRAISING_VERSION );
		// list  campaign css
		wp_register_style( 'wfp_single_campaign_css', WFP_FUNDRAISING_PLUGIN_URL. 'assets/public/css/donate/campaign.css', false, WFP_FUNDRAISING_VERSION );
		// single page
		wp_register_style( 'wfp_single_css', WFP_FUNDRAISING_PLUGIN_URL. 'assets/public/css/single/single-page.css', false, WFP_FUNDRAISING_VERSION );
		// libarey css
		wp_register_style( 'wfp_css_libarey', WFP_FUNDRAISING_PLUGIN_URL. 'assets/public/css/libarey/libarey.css', false, WFP_FUNDRAISING_VERSION );
		// master css
		wp_register_style( 'wfp_css_master', WFP_FUNDRAISING_PLUGIN_URL. 'assets/public/css/global/master.css', false, WFP_FUNDRAISING_VERSION );
		// checkout css
		wp_register_style( 'wfp_css_checkout', WFP_FUNDRAISING_PLUGIN_URL. 'assets/public/css/checkout/checkout.css', false, WFP_FUNDRAISING_VERSION );
		// responsive master
		wp_register_style( 'wfp_responsive_css_master', WFP_FUNDRAISING_PLUGIN_URL. 'assets/public/css/responsive.css', false, WFP_FUNDRAISING_VERSION );
       
		// donation public script
		wp_register_script( 'wfp_donation_form_script', WFP_FUNDRAISING_PLUGIN_URL. 'assets/public/script/donate/donate-form-front.js', array('jquery'), WFP_FUNDRAISING_VERSION, false);
		// from step script
		wp_register_script( 'wfp_campaign_form_step', WFP_FUNDRAISING_PLUGIN_URL. 'assets/public/script/donate/dashboard/lib/forms-setp.js', array('jquery'), WFP_FUNDRAISING_VERSION, false);
		// dashboard script
		wp_register_script( 'wfp_dashboard_script', WFP_FUNDRAISING_PLUGIN_URL. 'assets/public/script/donate/dashboard/dashboard.js', array('jquery'), WFP_FUNDRAISING_VERSION, false);
		// login script
		wp_register_script( 'wfp_login_script', WFP_FUNDRAISING_PLUGIN_URL. 'assets/public/script/donate/dashboard/login.js', array('jquery'), WFP_FUNDRAISING_VERSION, false);
		// chart js
		wp_register_script( 'chartjs', WFP_FUNDRAISING_PLUGIN_URL. 'assets/public/script/donate/dashboard/chart.min.js', array('jquery'), WFP_FUNDRAISING_VERSION, false);
		// magnific popup js
		wp_register_script( 'magnific_js', WFP_FUNDRAISING_PLUGIN_URL. 'assets/public/script/single-page/jquery.magnific-popup.min.js', array('jquery'), WFP_FUNDRAISING_VERSION, false);
		// single script
		wp_register_script( 'wfp_single_script', WFP_FUNDRAISING_PLUGIN_URL. 'assets/public/script/single-page/single-page.js', array('jquery'), WFP_FUNDRAISING_VERSION, false);
		//essay pie chart
		wp_register_script( 'wfp_easy_pie_script', WFP_FUNDRAISING_PLUGIN_URL. 'assets/public/script/single-page/easy-pie-chart.js', array('jquery'), WFP_FUNDRAISING_VERSION, false);
		// stripe script
		wp_register_script( 'wfp_stripe_checkout_js', 'https://checkout.stripe.com/checkout.js', array('jquery'), WFP_FUNDRAISING_VERSION, false);
						 							

		// welcome css
		wp_register_style( 'wfp_welcome_style_css', WFP_FUNDRAISING_PLUGIN_URL. 'views/welcome/css/welcome.css', false, WFP_FUNDRAISING_VERSION );
		// welcome script
		wp_register_script( 'wfp_welcome_style_script', WFP_FUNDRAISING_PLUGIN_URL.'views/welcome/script/welcome.js', array('jquery'), WFP_FUNDRAISING_VERSION, false);
		
		

		// wp css
		wp_enqueue_style( 'dashicons' );
		wp_enqueue_style( 'wp-color-picker');
		
		// wp color script
		wp_enqueue_script('wp-color-picker');
		
		// flatpickr date picker
		wp_enqueue_style( 'flatpickr-wfp' );
		wp_enqueue_script( 'flatpickr-wfp' );
		
		// select 2
		wp_enqueue_style( 'select2' );
		wp_enqueue_script( 'select2' );
		
		// modal for payment
		wp_enqueue_script( 'wfp_payment_script_modal' );

	}
     
	 
	 
	 /**
	 * Currency format settings
	 */
	
	 public static function  wfp_number_format_currency($amount = '0'){
		 include(WFP_FUNDRAISING_PLUGIN_PATH.'country-module/country-info.php' );
		/*currency information*/
		$metaGeneralKey = 'wfp_general_options_data';
		$getMetaGeneralOp = get_option( $metaGeneralKey );
		$getMetaGeneral = isset($getMetaGeneralOp['options']) ? $getMetaGeneralOp['options'] : [];
		
		$defaultCurrencyInfo = isset($getMetaGeneral['currency']['name']) ? $getMetaGeneral['currency']['name'] : 'US-USD';
		$explCurr = explode('-', $defaultCurrencyInfo);
		$currCode = isset($explCurr[1]) ? $explCurr[1] : 'USD';
		
		$symbols = isset($countryList[current($explCurr)]['currency']['symbol']) ? $countryList[current($explCurr)]['currency']['symbol'] : '';
		$symbols = strlen($symbols) > 0 ? $symbols : $currCode;
		
		$defaultThou_seperator = isset($getMetaGeneral['currency']['thou_seperator']) ? $getMetaGeneral['currency']['thou_seperator'] : ',';
		
		$defaultDecimal_seperator = isset($getMetaGeneral['currency']['decimal_seperator']) ? $getMetaGeneral['currency']['decimal_seperator'] : '.';
		
		$defaultNumberDecimal = isset($getMetaGeneral['currency']['number_decimal']) ? $getMetaGeneral['currency']['number_decimal'] : '2';
		if($defaultNumberDecimal < 0){
			$defaultNumberDecimal = 0;
		}
		$userNumber = number_format($amount, $defaultNumberDecimal);
		
		$numberExplode = explode('.', $userNumber);
		$replaceNumber = str_replace([','], [$defaultThou_seperator], $numberExplode[0]);
		if(isset($numberExplode[1])){
			$replaceNumber .= $defaultDecimal_seperator.$numberExplode[1];
		}
		return $replaceNumber;
	 }
	 /**
	 * Currency icon format settings
	 */
	 public static function  wfp_number_format_currency_icon($showFormat = 'default', $space = 'off'){
		 include(WFP_FUNDRAISING_PLUGIN_PATH.'country-module/country-info.php' );
		 /*currency information*/
		$metaGeneralKey = 'wfp_general_options_data';
		$getMetaGeneralOp = get_option( $metaGeneralKey );
		$getMetaGeneral = isset($getMetaGeneralOp['options']) ? $getMetaGeneralOp['options'] : [];
		
		$defaultCurrencyInfo = isset($getMetaGeneral['currency']['name']) ? $getMetaGeneral['currency']['name'] : 'US-USD';
		$explCurr = explode('-', $defaultCurrencyInfo);
		$currCode = isset($explCurr[1]) ? $explCurr[1] : 'USD';
		
		$symbols = isset($countryList[current($explCurr)]['currency']['symbol']) ? $countryList[current($explCurr)]['currency']['symbol'] : '';
		$symbols = strlen($symbols) > 0 ? $symbols : $currCode;
		
		
		$defultDisplayCurrency = isset($getMetaGeneral['currency']['display']) ? $getMetaGeneral['currency']['display'] : 'symbol';
		
		$defaultPosition = isset($getMetaGeneral['currency']['position']) ? $getMetaGeneral['currency']['position'] : 'left';
		
		$spaceData = ($space == 'on') ? '&nbsp;' : '';
		
		if($defultDisplayCurrency == 'code'){
			if($defaultPosition == 'right'){
				return ($showFormat == 'right') ? $spaceData.$currCode : '' ;
			}else{
				return ($showFormat == 'left') ? $currCode.$spaceData : '' ;
			}
			
		}else if($defultDisplayCurrency == 'symbol'){
			if($defaultPosition == 'right'){
				return ($showFormat == 'right') ? $spaceData.$symbols : '' ;
			}else{
				return ($showFormat == 'left') ? $symbols.$spaceData : '' ;
			}
			
		}else if($defultDisplayCurrency == 'both'){
			return ($showFormat == 'right') ? $spaceData.$currCode : $symbols.$spaceData ;
		
		}else{
			if($defaultPosition == 'right'){
				return ($showFormat == 'right') ? $spaceData.$symbols : '' ;
			}else{
				return ($showFormat == 'left') ? $symbols.$spaceData : '' ;
			}
		}
		
	 }
	 
	 /*check page when plugin active*/
	public static function wfp_the_slug_exists($post_name) {
		global $wpdb;
		$table_prefix = $wpdb->prefix.'posts';
		if($wpdb->get_row("SELECT post_name FROM $table_prefix WHERE post_name = '" . $post_name . "'", 'ARRAY_A')) {
			return true;
		} else {
			return false;
		}
	}
	
	
	/**
	* Create page when setup plugin
	*/
	public function wfp_create_page_setup(){
		if (is_admin()){
			$pageArray = self::default_custom_page();
			$current_id = get_current_user_id();
			foreach($pageArray as $page=>$name){
				$check_title = ucfirst($name);
				if($page == 'campaign'){
					$check_content = '[wfp-'.$page.' limit="9" layout="grid" column="3" orderby="post_date" order="DESC" categories="" goal="Yes" user="Yes" category="Yes" title="Yes" excerpt="Yes" featured="Yes"]';	
				}else{
					$check_content = '[wfp-'.$page.']';
				}
				
				$blog_page_check = get_page_by_path( 'wfp-'.$page, 'OBJECT', 'page');
				$data_page = array(
					'post_type' => 'page',
					'post_title' => $check_title,
					'post_name' => 'wfp-'.$page,
					'post_content' => $check_content,
					'post_status' => 'publish',
					'post_author' => $current_id,
					'comment_status' => 'closed',
					'post_slug' => 'wfp-'.$page
				);
				if(!isset($blog_page_check->ID) ){
					wp_insert_post($data_page);
				}
			}
			
		}
	 }
	 
	 /**###################**/
	 
	/*
	* Custom Create page
	*/
	public static function default_custom_page(){
		return ['dashboard' => 'Dashboard', 'checkout' => 'Checkout', 'success' => 'Success', 'cancel' => 'Faild Transaction ', 'campaign' => 'Campaign'];
	}
	/**
	* Share options 
	*/ 
	public static function share_options(){
		
		$link['facebook'] = ['label' => 'Facebook',  'url' => 'http://www.facebook.com/sharer.php', 'icon' => 'met-social met-social-facebook', 'params' => [ 'u' => '[%url%]', 't' => '[%title%]', 'v' => 3] ];
		$link['twitter'] = [ 'label' => 'Twitter', 'url' => 'https://twitter.com/intent/tweet', 'icon' => 'met-social met-social-twitter', 'params' => [ 'text' => '[%title%] [%url%]', 'original_referer' => '[%url%]', 'related' => '[%author%]'] ];
		$link['linkedin'] = [ 'label' => 'LinkedIn', 'url' => 'https://www.linkedin.com/shareArticle', 'icon' => 'met-social met-social-linkedin', 'params' => [ 'url' => '[%url%]', 'title' => '[%title%]', 'summary' => '[%details%]', 'source' => '[%source%]', 'mini' => true] ];
		$link['pinterest'] = [ 'label' => 'Pinterest', 'url' => 'https://pinterest.com/pin/create/button/', 'icon' => 'met-social met-social-pinterest', 'params' => [ 'url' => '[%url%]', 'media' => '[%media%]', 'description' => '[%details%]'] ];
		$link['whatsapp'] = [ 'label' => 'WhatsApp', 'url' => 'whatsapp://send', 'icon' => 'met-social met-social-whatsapp', 'params' => [ 'text' => '[%title%] [%url%]'] ];
		$link['email'] = [ 'label' => 'Email', 'url' => 'mailto:', 'icon' => 'met-social met-social-email', 'params' => [ 'body' => 'Title: [%title%] \n\n URL: [%url%]', 'subject' => '[%title%]']];
		
		return apply_filters('wfp_single_social_providers', $link);
	}

	// share provider
	public static function generate_social(){
		$link = self::share_options();
		if( empty($link) && !is_array($link) ){
			return '';
		}

		global $post;

		global $currentUrl, $title,$author, $details, $source, $media, $app_id;
		$currentUrl = (isset($_SERVER['HTTPS']) && $_SERVER['HTTPS'] === 'on' ? 'https' : 'http') . '://'.$_SERVER['HTTP_HOST'].$_SERVER['REQUEST_URI'];
		if(is_object($post) && isset($post->ID)){
			$currentUrl = get_permalink();
			
		}
		$postId = isset($post->ID) ? $post->ID : 0;
		
		$current_id = get_current_user_id();
		
		$author = 'xpeedstudio';
		
		$details = '';
		if(isset($post->post_excerpt) && strlen($post->post_excerpt) > 2){
			$details = $post->post_excerpt;
		}
		$title = get_the_title();
		
		$source = get_bloginfo();
		$thumbnail_src = wp_get_attachment_image_src( get_post_thumbnail_id( $postId ), 'full' );
		
		$custom_logo_id = get_theme_mod( 'custom_logo' );
		$image = wp_get_attachment_image_src( $custom_logo_id , 'full' );
		$customLogo = isset($image[0]) ? $image[0] : '';
		
		$media = isset($thumbnail_src[0]) ? $thumbnail_src[0] : $customLogo;
		$app_id = '463603197734720';

		$metaSocialKey = 'wfp_share_media_options';
		$getMetaSocialOp = get_option( $metaSocialKey );
		$getMetaSocial = isset($getMetaSocialOp['media']) ? $getMetaSocialOp['media'] : [];
		
		$linkData = '';
		$linkData .= '<ul class="wfp-share-media">';
		foreach($link as $k=>$v){
			
			if( !isset($getMetaSocial[$k]['enable'] )){
				continue;
			}
			$label = isset($v['label']) ? $v['label'] : '';
			$url_get = isset($v['url']) ? $v['url'] : '';
			$params_data = isset($v['params']) ? $v['params'] : '';
			$onclick = isset($v['onclick']) ? $v['onclick'] : 'wfp_share(this)';
			$icon = isset($v['icon']) ? $v['icon'] : '';
			
			$urlCon = array_combine(
								array_keys($params_data ), 
								array_map( function($v){ 
								global $currentUrl, $title, $author, $details, $source, $media, $app_id;
								return str_replace(['[%url%]', '[%title%]', '[%author%]', '[%details%]', '[%source%]', '[%media%]', '[%app_id%]'], [$currentUrl, $title, $author, $details, $source, $media, $app_id], $v); 
								}, $params_data)
						);
			
			$params = http_build_query($urlCon, '&');
			if( !empty($url_get) ){
				$linkData .= '<li> <a href="javascript:void();"  class="wfp-'.$k.'" title="'.$label.'" id="wfp-'.$k.'" data-link="'.$url_get.'?'.$params.'" onclick="'.$onclick.'"> <i class="'.$icon.'"></i> </a></li>';
			}else{
				$url_get = $currentUrl;
				$linkData .= '<li> <a href="javascript:void();" class="wfp-'.$k.'" title="'.$label.'" id="wfp-'.$k.'" data-link="'.$url_get.'" onclick="'.$onclick.'"> <i class="'.$icon.'"></i> </a></li>';
			}
			
		}
		$linkData .= '</ul>';

		return $linkData;
		
	}
	/**
	* Global options 
	*/ 
	public static function global_options(){
		return [
				'goal_setup' => ['name' => 'Goal Setup', 'note' => 'Enable goal setting in all compaign forms. - Tab "Goal Setup" in Campaign Form.'],
				'pledge_setup' => ['name' => 'Pledge Setup', 'note' => 'Enable pledge setting in all compaign forms for Crowdfunding. - Tab "Pledge Setup" in Campaign Form.'],
				'custom_fileds' => ['name' => 'Custom Fileds', 'note' => 'Use custom fileds in forms like as [Phone, Address etc.] - Section "Form Content" in Campaign Form.'],
				'additional_fees' => ['name' => 'Additional Fees', 'note' => 'Enable vat(%) amount for each payment. - Section "General" in Campaign Form.'],
				'limit_setup' => ['name' => 'Limit Options', 'note' => 'Set limit amount (min, max) on the campaign submission form. - Section "General" in Campaign Form.'],
				'contributor_info' => ['name' => 'Contributor Info', 'note' => 'Enable this option to display the contributors for this Campaign. - Section "Settings" in Campaign Form.'],
			];
	}
	/**
	* Default custom filed in donational submit form
	*/ 
	public static function default_addition_filed(){
		return [ (object)['type' => 'text', 'lebel' => 'First Name', 'default' => '', 'required' => 'Yes'], (object)['type' => 'text', 'lebel' => 'Last Name', 'default' => '', 'required' => 'Yes'], (object)['type' => 'text', 'lebel' => 'Email Address', 'default' => '', 'required' => 'Yes'] ];
	}
	
	/*
	* Setup Plugin Option data
	*/
	
	public static function default_setup(){
		$url = admin_url().'edit.php?post_type='.self::post_type().'&page=settings&tab=gateway';
		
		return [
			'welcome' =>  ['headding' => 'Welcome WP Foundrasing', 'details' => 'Welcome to our WP Fundraising for Single Donation & Crowdfunding', 'img_url' => WFP_FUNDRAISING_PLUGIN_URL.'/views/welcome/image/screenshot-welcome.png', 'button' => ['pre' => 'Cancel', 'pre_type' => 'close', 'next' => 'Start', 'next_type' => 'next', 'data' => ''], 'return' => ['type' => 'next', 'location' => '']
			],
			'campaign' => ['headding' => 'Campaign Format', 'details' => 'Select once format for Campaign then click "Ok" button and go to next step.', 'img_url' => '', 'button' => [ 'pre' => 'Previous', 'pre_type' => 'pre', 'next' => 'Ok', 'next_type' => 'install' ], 'data' => 'include/setup-campaign.php'
			],
			
			'payment_type'  => ['headding' => 'Payment Getway', 'details' => 'Select payment getway for Campaigns and click "Select" button and go to next step.', 'img_url' => '',  'button' => ['pre' => 'Previous',  'pre_type' => 'pre', 'next' => 'Select', 'next_type' => 'install'], 'data' => 'include/setup-payment-type.php'
			],
			/*'payment_method'  => ['headding' => 'Payment Method', 'details' => '', 'img_url' => '', 'button' => ['pre' => 'Previous',  'pre_type' => 'pre', 'next' => 'Setup', 'next_type' => 'install'], 'data' => 'include/setup-payment-method.php'
			],
			'currency' => ['headding' => 'Currency & Country Selection', 'details' => '', 'img_url' => '', 'button' => ['pre' => 'Skip', 'pre_type' => 'skip',  'next' => 'Install', 'next_type' => 'install'], 'data' => 'include/setup-currency.php'
			],*/
			'finish'   => ['headding' => 'Finish Setup..', 'details' => 'Click this finish button and complete your basic setup process and go to next settings.', 'img_url' => '', 'button' => ['pre' => 'Previous',  'pre_type' => 'pre', 'next' => 'Finish', 'next_type' => 'finish'], 'data' => '', 'return' => ['type' => 'redirect', 'location' => $url]
			],
		];
	}
	
	public static function check_setup($page = 'settings'){
		if($page === 'settings'){
			return true;
		}
		$metaSetupKey = 'wfp_setup_services_data';
		$getSetUpData =  get_option( $metaSetupKey );
		$gateWaysData = isset($getSetUpData['services']) ? $getSetUpData['services'] : '';
		$url = admin_url().'edit.php?post_type='.self::post_type().'&page=settings';
		if(empty($gateWaysData)){
			echo '
				<script>
					//setTimeout(function() {
					  window.location.href = "'.$url.'";
					//}, 20);
				</script>
				';
			wp_die();
		}else{
			$setpData = self::default_setup();
			$checkFinish = isset($getSetUpData['services']['finish']) ? $getSetUpData['services']['finish'] : current(array_keys(self::default_setup()));
			if($checkFinish != 'finish'){
				echo '
				<script>
					//setTimeout(function() {
					  window.location.href = "'.$url.'";
					//}, 20);
				</script>
				';
			wp_die();
			}
		}
	}
	
	public static function check_setup_page(){		
		$metaSetupKey = 'wfp_setup_services_data';
		$getSetUpData =  get_option( $metaSetupKey );
		$gateWaysData = isset($getSetUpData['services']) ? $getSetUpData['services'] : [];
		if(empty($gateWaysData)){
			return true;
		}else{
			$checkFinish = isset($getSetUpData['services']['finish']) ? $getSetUpData['services']['finish'] : current(array_keys(self::default_setup()));
			if($checkFinish != 'finish'){
				return true;
			}
		}
		return false;
	}
	
	public static function sanitize($value, $senitize_func = 'sanitize_text_field'){
        $senitize_func = (in_array($senitize_func, [
                'sanitize_email', 
                'sanitize_file_name', 
                'sanitize_hex_color', 
                'sanitize_hex_color_no_hash', 
                'sanitize_html_class', 
                'sanitize_key', 
                'sanitize_meta', 
                'sanitize_mime_type',
                'sanitize_sql_orderby',
                'sanitize_option',
                'sanitize_text_field',
                'sanitize_title',
                'sanitize_title_for_query',
                'sanitize_title_with_dashes',
                'sanitize_user',
                'esc_url_raw',
                'wp_filter_nohtml_kses',
            ])) ? $senitize_func : 'sanitize_text_field';
        
        if(!is_array($value)){
            return $senitize_func($value);
        }else{
            return array_map(function($inner_value) use ($senitize_func){
                return self::sanitize($inner_value, $senitize_func);
            }, $value);
        }
    }
	
	 /*
	 * email partten
	 */
	 public static function valid_email($str) {
		return (!preg_match("/^([a-z0-9\+_\-]+)(\.[a-z0-9\+_\-]+)*@([a-z0-9\-]+\.)+[a-z]{2,6}$/ix", $str)) ? FALSE : TRUE;
	}	
	
	/*Donate meta data for fundraising */
	
	public static function wfp_update_metadata($table = '', $post_id = 0, $meta_key = '', $meta_value = '', $unique = true){
		global $wpdb;
		$meta_value = is_array($meta_value) ? serialize($meta_value) : $meta_value;
		
		$myrows = $wpdb->get_var( "SELECT COUNT(*) FROM `$table` WHERE 1 = 1 AND meta_key = '".$meta_key."' AND donate_id = ".$post_id."");
		if($myrows > 0 && $unique == true){
			$wpdb->update( $table, ['meta_value' => $meta_value], ['meta_key' => $meta_key, 'donate_id' => $post_id] );
			return true;
		}else{
			$wpdb->insert( $table, ['donate_id' => $post_id, 'meta_key' => $meta_key, 'meta_value' => $meta_value]);
			return true;
		}
		
	}
	public static function wfp_get_metadata($table = '', $post_id = 0, $meta_key = ''){
		global $wpdb;
		$myrows = $wpdb->get_results( "SELECT `meta_value` FROM `$table` WHERE 1 = 1 AND `meta_key` = '".$meta_key."' AND `donate_id` = ".$post_id."" );
		$result = isset($myrows[0]->meta_value) ? $myrows[0]->meta_value : '';
		return (@unserialize($result) !== false) ? unserialize($result) : $result;
	}
	
	
	/*Check plugin of Install or active*/
	public static function missing_woocommerce() {
		if ( isset( $_GET['activate'] ) ) {
			unset( $_GET['activate'] );
		}
		$metaSetupKey = 'wfp_setup_services_data';
		$getSetUpData =  get_option( $metaSetupKey );
		$gateCampaignData = isset($getSetUpData['services']['payment']) ? $getSetUpData['services']['payment'] : 'default';
		if($gateCampaignData == 'default'){
			$btn['status'] = false;
			return $btn;
		}
		
		if ( file_exists( WP_PLUGIN_DIR . '/woocommerce/woocommerce.php' ) ) {
			if ( !is_plugin_active( 'woocommerce/woocommerce.php' ) ) {
				$btn['label'] = esc_html__('Activate Woocommerce', 'elementskit');
				$btn['url'] = wp_nonce_url( 'plugins.php?action=activate&plugin=woocommerce/woocommerce.php&plugin_status=all&paged=1', 'activate-plugin_woocommerce/woocommerce.php' );
				
				$btn['status'] = true;
			}else{
				$btn['status'] = false;
			}
		} else {
			$btn['label'] = esc_html__('Install Woocommerce', 'elementskit');
			$btn['url'] = wp_nonce_url( self_admin_url( 'update.php?action=install-plugin&plugin=woocommerce' ), 'install-plugin_woocommerce' );
			$btn['status'] = true;
		
		}
		return $btn;
	}
	public static function instance(){
        if (!self::$instance){
            self::$instance = new self();
        }
        return self::$instance;
    }
}