<?php
if ( ! defined( 'ABSPATH' ) ) die( 'Forbidden' ); 
/**
 * Plugin Name: Wp Fundraising Donation
 * Description: The most popular fundraising plugin for Donate and Crowdfunding Platform. Most advanced features in here.
 * Plugin URI: https://wpmet.com/
 * Author: Wpmet
 * Version: 1.0.9
 * Author URI: https://wpmet.com/
 *
 * Text Domain: wp-fundraising
 *
 * @package WpFundraising
 * @category Pro
 *
 * License description goes here.
 */


/**
 * Defining static values as global constants
 * @since 1.0.0
 */
define( 'WFP_FUNDRAISING_VERSION', '1.0.7');
define( 'WFP_FUNDRAISING_PREVIOUS_STABLE_VERSION', '1.0.6' );

define( 'WFP_FUNDRAISING_KEY', 'wp_fundraising' );

define( 'WFP_FUNDRAISING_TEXT_DOMAIN', 'wp-fundraising' );

define( 'WFP_FUNDRAISING_FILE_', __FILE__ );
define( "WFP_FUNDRAISING_PLUGIN_PATH", plugin_dir_path( WFP_FUNDRAISING_FILE_ ) );
define( 'WFP_FUNDRAISING_PLUGIN_URL', plugin_dir_url( WFP_FUNDRAISING_FILE_ ) );


// initiate actions
add_action( 'plugins_loaded', 'wfp_donate_load_plugin_textdomain' );

add_action( 'init', '__page_create' );

/**
 * Load Fundraising textdomain.
 * @since 1.0.0
 * @return void
 */
function wfp_donate_load_plugin_textdomain() {
	load_plugin_textdomain( 'wp-fundraising');
	
	// modify permalink structure by postname
	add_action( 'init', function() {
		global $wp_rewrite;
		$wp_rewrite->set_permalink_structure('/%postname%/');
		$wp_rewrite->flush_rules();
	} );

	/**
	 * Load Review Loader main page.
	 * @since 1.0.0
	 * @return plugin output
	 */
	require_once(WFP_FUNDRAISING_PLUGIN_PATH.'init.php');
	
	new \WfpFundraising\Init();

	// add action page hook
	add_filter( 'plugin_action_links_' . plugin_basename( __FILE__ ), 'wfp_action_links' );

	// include woocommerce services
	require_once(WFP_FUNDRAISING_PLUGIN_PATH.'apps/wfpwoocommerce.php');
}

function __page_create(){
	// action init rest	
	$version = get_option( 'wfp_fundraising_version', '1.0.0');
	
	if ( $version !== WFP_FUNDRAISING_VERSION ) {
		//table setup
		\WfpFundraising\Apps\Fundraising::instance()->wfp_action_create_table_donation();
		// set up page
		\WfpFundraising\Apps\Settings::instance()->wfp_create_page_setup();
	}
	
}

// added custom link
function wfp_action_links($links){
	$links[] = '<a href="' . admin_url( 'edit.php?post_type=wp-fundraising&page=settings' ).'"> '. __('Settings').'</a>';
	$links[] = '<a href="' . admin_url( 'post-new.php?post_type=wp-fundraising' ).'" target="_blank">'. __('Add').'</a>';
	return $links;
}


// plugin deactive
add_action( 'deactivated_plugin', 'wfp_plugin_deactivation', 10, 2 );
function wfp_plugin_deactivation(  $plugin, $network_activation ) {
	if ( plugin_basename( __FILE__ ) == $plugin){
		$option_name = [ 'wfp_setup_services_data', 'wfp_fundraising_version'];
		if( is_array($option_name) && sizeof($option_name) > 0):
			foreach($option_name as $v):
				delete_option($v);
				delete_site_option($v);
			endforeach;
		endif;
	}
}
	
